@@ -41,8 +41,7 @@ REDIS_ENV_KEYS = [
 # Old key -> new key
 DEPRECATIONS = {
     "geoip": "events.context_processors.geoip",
-    "redis.broker_url": "broker.url",
-    "redis.broker_transport_options": "broker.transport_options",
+    "worker.concurrency": "worker.threads",
     "redis.cache_timeout": "cache.timeout",
     "redis.cache_timeout_flows": "cache.timeout_flows",
     "redis.cache_timeout_policies": "cache.timeout_policies",
@@ -367,6 +366,8 @@ def django_db_config(config: ConfigLoader | None = None) -> dict:
     # See https://github.com/goauthentik/authentik/issues/14320
     pool_options = False
 
+    conn_options = config.get_dict_from_b64_json("postgresql.conn_options", default={})
+
     db = {
         "default": {
             "ENGINE": "authentik.root.db",
@@ -381,6 +382,7 @@ def django_db_config(config: ConfigLoader | None = None) -> dict:
                 "sslcert": config.get("postgresql.sslcert"),
                 "sslkey": config.get("postgresql.sslkey"),
                 "pool": pool_options,
+                **conn_options,
             },
             "CONN_MAX_AGE": config.get_optional_int("postgresql.conn_max_age", 0),
             "CONN_HEALTH_CHECKS": config.get_bool("postgresql.conn_health_checks", False),
@@ -410,8 +412,14 @@ def django_db_config(config: ConfigLoader | None = None) -> dict:
         if conn_max_age is not UNSET:
             db["default"]["CONN_MAX_AGE"] = conn_max_age
 
+    all_replica_conn_options = config.get_dict_from_b64_json(
+        "postgresql.replica_conn_options",
+        default={},
+    )
+
     for replica in config.get_keys("postgresql.read_replicas"):
         _database = deepcopy(db["default"])
+
         for setting, current_value in db["default"].items():
             if isinstance(current_value, dict):
                 continue
@@ -420,12 +428,23 @@ def django_db_config(config: ConfigLoader | None = None) -> dict:
             )
             if override is not UNSET:
                 _database[setting] = override
+
+        for option in conn_options.keys():
+            _database["OPTIONS"].pop(option, None)
+
         for setting in db["default"]["OPTIONS"].keys():
             override = config.get(
                 f"postgresql.read_replicas.{replica}.{setting.lower()}", default=UNSET
             )
             if override is not UNSET:
                 _database["OPTIONS"][setting] = override
+
+        _database["OPTIONS"].update(all_replica_conn_options)
+        replica_conn_options = config.get_dict_from_b64_json(
+            f"postgresql.read_replicas.{replica}.conn_options", default={}
+        )
+        _database["OPTIONS"].update(replica_conn_options)
+
         db[f"replica_{replica}"] = _database
     return db
 
