@@ -19,7 +19,7 @@ from packaging.version import Version, parse
 from rest_framework.serializers import Serializer
 from structlog.stdlib import get_logger
 
-from authentik import __version__, get_build_hash
+from authentik import authentik_build_hash, authentik_version
 from authentik.blueprints.models import ManagedModel
 from authentik.brands.models import Brand
 from authentik.core.models import (
@@ -35,10 +35,12 @@ from authentik.events.models import Event, EventAction
 from authentik.lib.config import CONFIG
 from authentik.lib.models import InheritanceForeignKey, SerializerModel
 from authentik.lib.sentry import SentryIgnoredException
-from authentik.lib.utils.errors import exception_to_string
+from authentik.lib.utils.time import fqdn_rand
 from authentik.outposts.controllers.k8s.utils import get_namespace
+from authentik.tasks.schedules.common import ScheduleSpec
+from authentik.tasks.schedules.models import ScheduledModel
 
-OUR_VERSION = parse(__version__)
+OUR_VERSION = parse(authentik_version())
 OUTPOST_HELLO_INTERVAL = 10
 LOGGER = get_logger()
 
@@ -115,7 +117,7 @@ class OutpostServiceConnectionState:
     healthy: bool
 
 
-class OutpostServiceConnection(models.Model):
+class OutpostServiceConnection(ScheduledModel, models.Model):
     """Connection details for an Outpost Controller, like Docker or Kubernetes"""
 
     uuid = models.UUIDField(default=uuid4, editable=False, primary_key=True)
@@ -145,11 +147,11 @@ class OutpostServiceConnection(models.Model):
     @property
     def state(self) -> OutpostServiceConnectionState:
         """Get state of service connection"""
-        from authentik.outposts.tasks import outpost_service_connection_state
+        from authentik.outposts.tasks import outpost_service_connection_monitor
 
         state = cache.get(self.state_key, None)
         if not state:
-            outpost_service_connection_state.delay(self.pk)
+            outpost_service_connection_monitor.send_with_options(args=(self.pk), rel_obj=self)
             return OutpostServiceConnectionState("", False)
         return state
 
@@ -160,6 +162,20 @@ class OutpostServiceConnection(models.Model):
         # since the response doesn't use the correct inheritance
         return ""
 
+    @property
+    def schedule_specs(self) -> list[ScheduleSpec]:
+        from authentik.outposts.tasks import outpost_service_connection_monitor
+
+        return [
+            ScheduleSpec(
+                actor=outpost_service_connection_monitor,
+                uid=self.name,
+                args=(self.pk,),
+                crontab="3-59/15 * * * *",
+                send_on_save=True,
+            ),
+        ]
+
 
 class DockerServiceConnection(SerializerModel, OutpostServiceConnection):
     """Service Connection to a Docker endpoint"""
@@ -244,7 +260,7 @@ class KubernetesServiceConnection(SerializerModel, OutpostServiceConnection):
         return "ak-service-connection-kubernetes-form"
 
 
-class Outpost(SerializerModel, ManagedModel):
+class Outpost(ScheduledModel, SerializerModel, ManagedModel):
     """Outpost instance which manages a service user and token"""
 
     uuid = models.UUIDField(default=uuid4, editable=False, primary_key=True)
@@ -298,6 +314,21 @@ class Outpost(SerializerModel, ManagedModel):
         """Username for service user"""
         return f"ak-outpost-{self.uuid.hex}"
 
+    @property
+    def schedule_specs(self) -> list[ScheduleSpec]:
+        from authentik.outposts.tasks import outpost_controller
+
+        return [
+            ScheduleSpec(
+                actor=outpost_controller,
+                uid=self.name,
+                args=(self.pk,),
+                kwargs={"action": "up", "from_cache": False},
+                crontab=f"{fqdn_rand('outpost_controller')} */4 * * *",
+                send_on_save=True,
+            ),
+        ]
+
     def build_user_permissions(self, user: User):
         """Create per-object and global permissions for outpost service-account"""
         # To ensure the user only has the correct permissions, we delete all of them and re-add
@@ -326,9 +357,8 @@ class Outpost(SerializerModel, ManagedModel):
                                 "While setting the permissions for the service-account, a "
                                 "permission was not found: Check "
                                 "https://goauthentik.io/docs/troubleshooting/missing_permission"
-                            )
-                            + exception_to_string(exc),
-                        ).set_user(user).save()
+                            ),
+                        ).with_exception(exc).set_user(user).save()
                 else:
                     app_label, perm = model_or_perm.split(".")
                     permission = Permission.objects.filter(
@@ -451,7 +481,7 @@ class OutpostState:
         """Check if outpost version matches our version"""
         if not self.version:
             return False
-        if self.build_hash != get_build_hash():
+        if self.build_hash != authentik_build_hash():
             return False
         return parse(self.version) != OUR_VERSION
 
