@@ -1,30 +1,34 @@
-from django.contrib.auth.signals import user_logged_out
 from django.db.models.signals import post_save, pre_delete
 from django.dispatch import receiver
-from django.http import HttpRequest
+from structlog.stdlib import get_logger
 
 from authentik.core.models import AuthenticatedSession, User
 from authentik.providers.oauth2.models import AccessToken, DeviceToken, RefreshToken
+from authentik.providers.oauth2.tasks import backchannel_logout_notification_dispatch
 
-
-@receiver(user_logged_out)
-def user_logged_out_oauth_tokens_removal(sender, request: HttpRequest, user: User, **_):
-    """Revoke tokens upon user logout"""
-    if not request.session or not request.session.session_key:
-        return
-    AccessToken.objects.filter(
-        user=user,
-        session__session__session_key=request.session.session_key,
-    ).delete()
+LOGGER = get_logger()
 
 
 @receiver(pre_delete, sender=AuthenticatedSession)
-def user_session_deleted_oauth_tokens_removal(sender, instance: AuthenticatedSession, **_):
+def user_session_deleted_oauth_backchannel_logout_and_tokens_removal(
+    sender, instance: AuthenticatedSession, **_
+):
     """Revoke tokens upon user logout"""
-    AccessToken.objects.filter(
+    LOGGER.debug("Sending back-channel logout notifications signal!", session=instance)
+
+    access_tokens = AccessToken.objects.filter(
         user=instance.user,
         session__session__session_key=instance.session.session_key,
-    ).delete()
+    )
+
+    backchannel_logout_notification_dispatch.send(
+        revocations=[
+            (token.provider_id, token.id_token.iss, token.session.user.uid)
+            for token in access_tokens
+        ],
+    )
+
+    access_tokens.delete()
 
 
 @receiver(post_save, sender=User)
