@@ -21,13 +21,15 @@ from authentik.sources.ldap.models import (
     flatten,
 )
 from authentik.sources.ldap.sync.base import BaseLDAPSynchronizer
+from authentik.tasks.models import Task
 
 
 class GroupLDAPSynchronizer(BaseLDAPSynchronizer):
     """Sync LDAP Users and groups into authentik"""
 
-    def __init__(self, source: LDAPSource):
-        super().__init__(source)
+    def __init__(self, source: LDAPSource, task: Task):
+        super().__init__(source, task)
+        self._source = source
         self.mapper = SourceMapper(source)
         self.manager = self.mapper.get_manager(Group, ["ldap", "dn"])
 
@@ -37,7 +39,7 @@ class GroupLDAPSynchronizer(BaseLDAPSynchronizer):
 
     def get_objects(self, **kwargs) -> Generator:
         if not self._source.sync_groups:
-            self.message("Group syncing is disabled for this Source")
+            self._task.info("Group syncing is disabled for this Source")
             return iter(())
         return self.search_paginator(
             search_base=self.base_dn_groups,
@@ -54,7 +56,7 @@ class GroupLDAPSynchronizer(BaseLDAPSynchronizer):
     def sync(self, page_data: list) -> int:
         """Iterate over all LDAP Groups and create authentik_core.Group instances"""
         if not self._source.sync_groups:
-            self.message("Group syncing is disabled for this Source")
+            self._task.info("Group syncing is disabled for this Source")
             return -1
         group_count = 0
         for group in page_data:
@@ -62,9 +64,9 @@ class GroupLDAPSynchronizer(BaseLDAPSynchronizer):
                 continue
             group_dn = flatten(flatten(group.get("entryDN", group.get("dn"))))
             if not (uniq := self.get_identifier(attributes)):
-                self.message(
+                self._task.info(
                     f"Uniqueness field not found/not set in attributes: '{group_dn}'",
-                    attributes=attributes.keys(),
+                    attributes=list(attributes.keys()),
                     dn=group_dn,
                 )
                 continue
