@@ -9,6 +9,7 @@ from ldap3 import SUBTREE
 from authentik.core.models import Group, User
 from authentik.sources.ldap.models import LDAP_DISTINGUISHED_NAME, LDAP_UNIQUENESS, LDAPSource
 from authentik.sources.ldap.sync.base import BaseLDAPSynchronizer
+from authentik.tasks.models import Task
 
 
 class MembershipLDAPSynchronizer(BaseLDAPSynchronizer):
@@ -16,8 +17,8 @@ class MembershipLDAPSynchronizer(BaseLDAPSynchronizer):
 
     group_cache: dict[str, Group]
 
-    def __init__(self, source: LDAPSource):
-        super().__init__(source)
+    def __init__(self, source: LDAPSource, task: Task):
+        super().__init__(source, task)
         self.group_cache: dict[str, Group] = {}
 
     @staticmethod
@@ -26,7 +27,7 @@ class MembershipLDAPSynchronizer(BaseLDAPSynchronizer):
 
     def get_objects(self, **kwargs) -> Generator:
         if not self._source.sync_groups:
-            self.message("Group syncing is disabled for this Source")
+            self._task.info("Group syncing is disabled for this Source")
             return iter(())
 
         # If we are looking up groups from users, we don't need to fetch the group membership field
@@ -45,7 +46,7 @@ class MembershipLDAPSynchronizer(BaseLDAPSynchronizer):
     def sync(self, page_data: list) -> int:
         """Iterate over all Users and assign Groups using memberOf Field"""
         if not self._source.sync_groups:
-            self.message("Group syncing is disabled for this Source")
+            self._task.info("Group syncing is disabled for this Source")
             return -1
         membership_count = 0
         for group in page_data:
@@ -94,7 +95,7 @@ class MembershipLDAPSynchronizer(BaseLDAPSynchronizer):
         # group_uniq might be a single string or an array with (hopefully) a single string
         if isinstance(group_uniq, list):
             if len(group_uniq) < 1:
-                self.message(
+                self._task.info(
                     f"Group does not have a uniqueness attribute: '{group_dn}'",
                     group=group_dn,
                 )
@@ -104,7 +105,7 @@ class MembershipLDAPSynchronizer(BaseLDAPSynchronizer):
             groups = Group.objects.filter(**{f"attributes__{LDAP_UNIQUENESS}": group_uniq})
             if not groups.exists():
                 if self._source.sync_groups:
-                    self.message(
+                    self._task.info(
                         f"Group does not exist in our DB yet, run sync_groups first: '{group_dn}'",
                         group=group_dn,
                     )
