@@ -23,13 +23,14 @@ from authentik.sources.ldap.models import (
 from authentik.sources.ldap.sync.base import BaseLDAPSynchronizer
 from authentik.sources.ldap.sync.vendor.freeipa import FreeIPA
 from authentik.sources.ldap.sync.vendor.ms_ad import MicrosoftActiveDirectory
+from authentik.tasks.models import Task
 
 
 class UserLDAPSynchronizer(BaseLDAPSynchronizer):
     """Sync LDAP Users into authentik"""
 
-    def __init__(self, source: LDAPSource):
-        super().__init__(source)
+    def __init__(self, source: LDAPSource, task: Task):
+        super().__init__(source, task)
         self.mapper = SourceMapper(source)
         self.manager = self.mapper.get_manager(User, ["ldap", "dn"])
 
@@ -39,7 +40,7 @@ class UserLDAPSynchronizer(BaseLDAPSynchronizer):
 
     def get_objects(self, **kwargs) -> Generator:
         if not self._source.sync_users:
-            self.message("User syncing is disabled for this Source")
+            self._task.info("User syncing is disabled for this Source")
             return iter(())
         return self.search_paginator(
             search_base=self.base_dn_users,
@@ -56,7 +57,7 @@ class UserLDAPSynchronizer(BaseLDAPSynchronizer):
     def sync(self, page_data: list) -> int:
         """Iterate over all LDAP Users and create authentik_core.User instances"""
         if not self._source.sync_users:
-            self.message("User syncing is disabled for this Source")
+            self._task.info("User syncing is disabled for this Source")
             return -1
         user_count = 0
         for user in page_data:
@@ -64,9 +65,9 @@ class UserLDAPSynchronizer(BaseLDAPSynchronizer):
                 continue
             user_dn = flatten(user.get("entryDN", user.get("dn")))
             if not (uniq := self.get_identifier(attributes)):
-                self.message(
+                self._task.info(
                     f"Uniqueness field not found/not set in attributes: '{user_dn}'",
-                    attributes=attributes.keys(),
+                    attributes=list(attributes.keys()),
                     dn=user_dn,
                 )
                 continue
@@ -112,6 +113,8 @@ class UserLDAPSynchronizer(BaseLDAPSynchronizer):
             else:
                 self._logger.debug("Synced User", user=ak_user.username, created=created)
                 user_count += 1
-                MicrosoftActiveDirectory(self._source).sync(attributes, ak_user, created)
-                FreeIPA(self._source).sync(attributes, ak_user, created)
+                MicrosoftActiveDirectory(self._source, self._task).sync(
+                    attributes, ak_user, created
+                )
+                FreeIPA(self._source, self._task).sync(attributes, ak_user, created)
         return user_count
