@@ -8,8 +8,7 @@ from django.test import TestCase
 from authentik.blueprints.tests import apply_blueprint
 from authentik.core.models import Group, User
 from authentik.core.tests.utils import create_test_admin_user
-from authentik.events.models import Event, EventAction, SystemTask
-from authentik.events.system_tasks import TaskStatus
+from authentik.events.models import Event, EventAction
 from authentik.lib.generators import generate_id, generate_key
 from authentik.lib.sync.outgoing.exceptions import StopSync
 from authentik.lib.utils.reflection import class_to_path
@@ -23,7 +22,7 @@ from authentik.sources.ldap.sync.forward_delete_users import DELETE_CHUNK_SIZE
 from authentik.sources.ldap.sync.groups import GroupLDAPSynchronizer
 from authentik.sources.ldap.sync.membership import MembershipLDAPSynchronizer
 from authentik.sources.ldap.sync.users import UserLDAPSynchronizer
-from authentik.sources.ldap.tasks import ldap_sync, ldap_sync_all
+from authentik.sources.ldap.tasks import ldap_sync, ldap_sync_page
 from authentik.sources.ldap.tests.mock_ad import mock_ad_connection
 from authentik.sources.ldap.tests.mock_freeipa import mock_freeipa_connection
 from authentik.sources.ldap.tests.mock_slapd import (
@@ -33,6 +32,7 @@ from authentik.sources.ldap.tests.mock_slapd import (
     user_in_slapd_cn,
     user_in_slapd_uid,
 )
+from authentik.tasks.models import Task
 
 LDAP_PASSWORD = generate_key()
 
@@ -54,9 +54,7 @@ class LDAPSyncTests(TestCase):
         """Test sync with missing page"""
         connection = MagicMock(return_value=mock_ad_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync.delay(str(self.source.pk), class_to_path(UserLDAPSynchronizer), "foo").get()
-        task = SystemTask.objects.filter(name="ldap_sync", uid="ldap:users:foo").first()
-        self.assertEqual(task.status, TaskStatus.ERROR)
+            ldap_sync_page.send(self.source.pk, class_to_path(UserLDAPSynchronizer), "foo")
 
     def test_sync_error(self):
         """Test user sync"""
@@ -74,7 +72,7 @@ class LDAPSyncTests(TestCase):
         self.source.save()
         connection = MagicMock(return_value=mock_ad_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             with self.assertRaises(StopSync):
                 user_sync.sync_full()
             self.assertFalse(User.objects.filter(username="user0_sn").exists())
@@ -105,7 +103,7 @@ class LDAPSyncTests(TestCase):
 
         # we basically just test that the mappings don't throw errors
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
 
     def test_sync_users_ad(self):
@@ -133,7 +131,7 @@ class LDAPSyncTests(TestCase):
         )
 
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
             user = User.objects.filter(username="user0_sn").first()
             self.assertEqual(user.attributes["foo"], "bar")
@@ -152,7 +150,7 @@ class LDAPSyncTests(TestCase):
         )
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
             self.assertTrue(User.objects.filter(username="user0_sn").exists())
             self.assertFalse(User.objects.filter(username="user1_sn").exists())
@@ -168,7 +166,7 @@ class LDAPSyncTests(TestCase):
         )
         connection = MagicMock(return_value=mock_freeipa_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
             self.assertTrue(User.objects.filter(username="user0_sn").exists())
             self.assertFalse(User.objects.filter(username="user1_sn").exists())
@@ -193,11 +191,11 @@ class LDAPSyncTests(TestCase):
         )
         connection = MagicMock(return_value=mock_freeipa_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
-            group_sync = GroupLDAPSynchronizer(self.source)
+            group_sync = GroupLDAPSynchronizer(self.source, Task())
             group_sync.sync_full()
-            membership_sync = MembershipLDAPSynchronizer(self.source)
+            membership_sync = MembershipLDAPSynchronizer(self.source, Task())
             membership_sync.sync_full()
 
             self.assertTrue(
@@ -230,9 +228,9 @@ class LDAPSyncTests(TestCase):
             parent_group = Group.objects.get(name=_user.username)
             self.source.sync_parent_group = parent_group
             self.source.save()
-            group_sync = GroupLDAPSynchronizer(self.source)
+            group_sync = GroupLDAPSynchronizer(self.source, Task())
             group_sync.sync_full()
-            membership_sync = MembershipLDAPSynchronizer(self.source)
+            membership_sync = MembershipLDAPSynchronizer(self.source, Task())
             membership_sync.sync_full()
             group: Group = Group.objects.filter(name="test-group").first()
             self.assertIsNotNone(group)
@@ -256,9 +254,9 @@ class LDAPSyncTests(TestCase):
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
             self.source.save()
-            group_sync = GroupLDAPSynchronizer(self.source)
+            group_sync = GroupLDAPSynchronizer(self.source, Task())
             group_sync.sync_full()
-            membership_sync = MembershipLDAPSynchronizer(self.source)
+            membership_sync = MembershipLDAPSynchronizer(self.source, Task())
             membership_sync.sync_full()
             group = Group.objects.filter(name="group1")
             self.assertTrue(group.exists())
@@ -290,11 +288,11 @@ class LDAPSyncTests(TestCase):
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
             self.source.save()
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
-            group_sync = GroupLDAPSynchronizer(self.source)
+            group_sync = GroupLDAPSynchronizer(self.source, Task())
             group_sync.sync_full()
-            membership_sync = MembershipLDAPSynchronizer(self.source)
+            membership_sync = MembershipLDAPSynchronizer(self.source, Task())
             membership_sync.sync_full()
             # Test if membership mapping based on memberUid works.
             posix_group = Group.objects.filter(name="group-posix").first()
@@ -327,11 +325,11 @@ class LDAPSyncTests(TestCase):
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
             self.source.save()
-            user_sync = UserLDAPSynchronizer(self.source)
+            user_sync = UserLDAPSynchronizer(self.source, Task())
             user_sync.sync_full()
-            group_sync = GroupLDAPSynchronizer(self.source)
+            group_sync = GroupLDAPSynchronizer(self.source, Task())
             group_sync.sync_full()
-            membership_sync = MembershipLDAPSynchronizer(self.source)
+            membership_sync = MembershipLDAPSynchronizer(self.source, Task())
             membership_sync.sync_full()
             # Test if membership mapping based on memberUid works.
             posix_group = Group.objects.filter(name="group-posix").first()
@@ -348,7 +346,7 @@ class LDAPSyncTests(TestCase):
         self.source.save()
         connection = MagicMock(return_value=mock_ad_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
 
     def test_tasks_openldap(self):
         """Test Scheduled tasks"""
@@ -363,7 +361,7 @@ class LDAPSyncTests(TestCase):
         self.source.save()
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
 
     def test_user_deletion(self):
         """Test user deletion"""
@@ -378,7 +376,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertFalse(User.objects.filter(username="not-in-the-source").exists())
 
     def test_user_deletion_still_in_source(self):
@@ -396,7 +394,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertTrue(User.objects.filter(username=username).exists())
 
     def test_user_deletion_no_sync(self):
@@ -413,7 +411,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertTrue(User.objects.filter(username="not-in-the-source").exists())
 
     def test_user_deletion_no_delete(self):
@@ -428,7 +426,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertTrue(User.objects.filter(username="not-in-the-source").exists())
 
     def test_group_deletion(self):
@@ -444,7 +442,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertFalse(Group.objects.filter(name="not-in-the-source").exists())
 
     def test_group_deletion_still_in_source(self):
@@ -462,7 +460,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertTrue(Group.objects.filter(name=groupname).exists())
 
     def test_group_deletion_no_sync(self):
@@ -479,7 +477,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertTrue(Group.objects.filter(name="not-in-the-source").exists())
 
     def test_group_deletion_no_delete(self):
@@ -494,7 +492,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
         self.assertTrue(Group.objects.filter(name="not-in-the-source").exists())
 
     def test_batch_deletion(self):
@@ -517,7 +515,7 @@ class LDAPSyncTests(TestCase):
 
         connection = MagicMock(return_value=mock_slapd_connection(LDAP_PASSWORD))
         with patch("authentik.sources.ldap.models.LDAPSource.connection", connection):
-            ldap_sync_all.delay().get()
+            ldap_sync.send(self.source.pk)
 
         self.assertFalse(User.objects.filter(username__startswith="not-in-the-source").exists())
         self.assertFalse(Group.objects.filter(name__startswith="not-in-the-source").exists())
