@@ -3,6 +3,8 @@
 from structlog.stdlib import get_logger
 
 from authentik.blueprints.apps import ManagedAppConfig
+from authentik.lib.utils.time import fqdn_rand
+from authentik.tasks.schedules.common import ScheduleSpec
 
 LOGGER = get_logger()
 
@@ -10,6 +12,7 @@ AUTHENTIK_SOURCES_OAUTH_TYPES = [
     "authentik.sources.oauth.types.apple",
     "authentik.sources.oauth.types.azure_ad",
     "authentik.sources.oauth.types.discord",
+    "authentik.sources.oauth.types.entra_id",
     "authentik.sources.oauth.types.facebook",
     "authentik.sources.oauth.types.github",
     "authentik.sources.oauth.types.gitlab",
@@ -40,3 +43,14 @@ class AuthentikSourceOAuthConfig(ManagedAppConfig):
             except ImportError as exc:
                 LOGGER.warning("Failed to load OAuth Source", exc=exc)
         return super().import_related()
+
+    @property
+    def tenant_schedule_specs(self) -> list[ScheduleSpec]:
+        from authentik.sources.oauth.tasks import update_well_known_jwks
+
+        return [
+            ScheduleSpec(
+                actor=update_well_known_jwks,
+                crontab=f"{fqdn_rand('update_well_known_jwks')} */3 * * *",
+            ),
+        ]
