@@ -1,40 +1,34 @@
 """Plex tasks"""
 
+from django.utils.translation import gettext_lazy as _
+from django_dramatiq_postgres.middleware import CurrentTask
+from dramatiq.actor import actor
 from requests import RequestException
 
-from authentik.events.models import Event, EventAction, TaskStatus
-from authentik.events.system_tasks import SystemTask
+from authentik.events.models import Event, EventAction
 from authentik.lib.utils.errors import exception_to_string
-from authentik.root.celery import CELERY_APP
 from authentik.sources.plex.models import PlexSource
 from authentik.sources.plex.plex import PlexAuth
+from authentik.tasks.models import Task
 
 
-@CELERY_APP.task()
-def check_plex_token_all():
-    """Check plex token for all plex sources"""
-    for source in PlexSource.objects.all():
-        check_plex_token.delay(source.slug)
-
-
-@CELERY_APP.task(bind=True, base=SystemTask)
-def check_plex_token(self: SystemTask, source_slug: int):
+@actor(description=_("Check the validity of a Plex source."))
+def check_plex_token(source_pk: str):
     """Check the validity of a Plex source."""
-    sources = PlexSource.objects.filter(slug=source_slug)
+    self: Task = CurrentTask.get_task()
+    sources = PlexSource.objects.filter(pk=source_pk)
     if not sources.exists():
         return
     source: PlexSource = sources.first()
-    self.set_uid(source.slug)
     auth = PlexAuth(source, source.plex_token)
     try:
         auth.get_user_info()
-        self.set_status(TaskStatus.SUCCESSFUL, "Plex token is valid.")
+        self.info("Plex token is valid.")
     except RequestException as exc:
         error = exception_to_string(exc)
         if len(source.plex_token) > 0:
             error = error.replace(source.plex_token, "$PLEX_TOKEN")
-        self.set_status(
-            TaskStatus.ERROR,
+        self.error(
             "Plex token is invalid/an error occurred:",
             error,
         )
