@@ -1,112 +1,123 @@
-import { CapabilitiesEnum, WithCapabilitiesConfig } from "#elements/mixins/capabilities";
-import "@goauthentik/admin/applications/ProviderSelectModal";
-import { iconHelperText } from "@goauthentik/admin/helperText";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import "@goauthentik/components/ak-file-input";
-import "@goauthentik/components/ak-radio-input";
-import "@goauthentik/components/ak-switch-input";
-import "@goauthentik/components/ak-text-input";
-import "@goauthentik/components/ak-textarea-input";
-import "@goauthentik/elements/Alert";
-import "@goauthentik/elements/forms/FormGroup";
-import "@goauthentik/elements/forms/HorizontalFormElement";
-import "@goauthentik/elements/forms/ModalForm";
-import { ModelForm } from "@goauthentik/elements/forms/ModelForm";
-import "@goauthentik/elements/forms/ProxyForm";
-import "@goauthentik/elements/forms/Radio";
-import "@goauthentik/elements/forms/SearchSelect/ak-search-select";
+import "#admin/applications/ProviderSelectModal";
+import "#components/ak-file-input";
+import "#components/ak-radio-input";
+import "#components/ak-slug-input";
+import "#components/ak-switch-input";
+import "#components/ak-text-input";
+import "#components/ak-textarea-input";
+import "#elements/Alert";
+import "#elements/forms/FormGroup";
+import "#elements/forms/HorizontalFormElement";
+import "#elements/forms/ModalForm";
+import "#elements/forms/ProxyForm";
+import "#elements/forms/Radio";
+import "#elements/forms/SearchSelect/ak-search-select";
 import "@patternfly/elements/pf-tooltip/pf-tooltip.js";
+import "./components/ak-backchannel-input.js";
+import "./components/ak-provider-search-input.js";
 
-import { msg } from "@lit/localize";
-import { TemplateResult, html, nothing } from "lit";
-import { customElement, property, state } from "lit/decorators.js";
-import { ifDefined } from "lit/directives/if-defined.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { ModelForm } from "#elements/forms/ModelForm";
+import { CapabilitiesEnum, WithCapabilitiesConfig } from "#elements/mixins/capabilities";
+import { navigate } from "#elements/router/RouterOutlet";
+
+import { iconHelperText } from "#admin/helperText";
+import { policyEngineModes } from "#admin/policies/PolicyEngineModes";
 
 import { Application, CoreApi, Provider } from "@goauthentik/api";
 
-import { policyOptions } from "./PolicyOptions.js";
-import "./components/ak-backchannel-input";
-import "./components/ak-provider-search-input";
+import { msg } from "@lit/localize";
+import { html, nothing, TemplateResult } from "lit";
+import { customElement, property, state } from "lit/decorators.js";
+import { ifDefined } from "lit/directives/if-defined.js";
 
 @customElement("ak-application-form")
 export class ApplicationForm extends WithCapabilitiesConfig(ModelForm<Application, string>) {
-    constructor() {
-        super();
-        this.handleConfirmBackchannelProviders = this.handleConfirmBackchannelProviders.bind(this);
-        this.makeRemoveBackchannelProviderHandler =
-            this.makeRemoveBackchannelProviderHandler.bind(this);
-    }
+    #api = new CoreApi(DEFAULT_CONFIG);
 
-    async loadInstance(pk: string): Promise<Application> {
-        const app = await new CoreApi(DEFAULT_CONFIG).coreApplicationsRetrieve({
+    protected override async loadInstance(pk: string): Promise<Application> {
+        const app = await this.#api.coreApplicationsRetrieve({
             slug: pk,
         });
+
         this.clearIcon = false;
         this.backchannelProviders = app.backchannelProvidersObj || [];
+
         return app;
     }
 
     @property({ attribute: false })
-    provider?: number;
+    public provider?: number;
 
     @state()
-    backchannelProviders: Provider[] = [];
+    protected backchannelProviders: Provider[] = [];
 
     @property({ type: Boolean })
-    clearIcon = false;
+    public clearIcon = false;
 
-    getSuccessMessage(): string {
+    protected override getSuccessMessage(): string {
         return this.instance
             ? msg("Successfully updated application.")
             : msg("Successfully created application.");
     }
 
-    async send(data: Application): Promise<Application | void> {
-        let app: Application;
-        data.backchannelProviders = this.backchannelProviders.map((p) => p.pk);
-        if (this.instance) {
-            app = await new CoreApi(DEFAULT_CONFIG).coreApplicationsUpdate({
-                slug: this.instance.slug,
-                applicationRequest: data,
-            });
-        } else {
-            app = await new CoreApi(DEFAULT_CONFIG).coreApplicationsCreate({
-                applicationRequest: data,
-            });
-        }
+    public override async send(applicationRequest: Application): Promise<Application | void> {
+        applicationRequest.backchannelProviders = this.backchannelProviders.map((p) => p.pk);
+
+        const currentSlug = this.instance?.slug;
+
+        const app = await (currentSlug
+            ? this.#api.coreApplicationsUpdate({
+                  applicationRequest,
+                  slug: currentSlug,
+              })
+            : this.#api.coreApplicationsCreate({ applicationRequest }));
+
+        const nextSlug = app.slug;
+
         if (this.can(CapabilitiesEnum.CanSaveMedia)) {
-            const icon = this.getFormFiles().metaIcon;
+            const icon = this.files().get("metaIcon");
+
             if (icon || this.clearIcon) {
-                await new CoreApi(DEFAULT_CONFIG).coreApplicationsSetIconCreate({
-                    slug: app.slug,
+                await this.#api.coreApplicationsSetIconCreate({
+                    slug: nextSlug,
                     file: icon,
                     clear: this.clearIcon,
                 });
             }
         } else {
-            await new CoreApi(DEFAULT_CONFIG).coreApplicationsSetIconUrlCreate({
-                slug: app.slug,
+            await this.#api.coreApplicationsSetIconUrlCreate({
+                slug: nextSlug,
                 filePathRequest: {
-                    url: data.metaIcon || "",
+                    url: applicationRequest.metaIcon || "",
                 },
             });
         }
+
+        if (currentSlug && currentSlug !== nextSlug) {
+            // TODO: This needs refining.
+            this.instancePk = nextSlug;
+            navigate(`/core/applications/${nextSlug}`);
+        }
+
         return app;
     }
 
-    handleConfirmBackchannelProviders(items: Provider[]) {
+    #handleConfirmBackchannelProviders = (items: Provider[]) => {
         this.backchannelProviders = items;
         this.requestUpdate();
-        return Promise.resolve();
-    }
 
-    makeRemoveBackchannelProviderHandler(provider: Provider) {
+        return Promise.resolve();
+    };
+
+    #makeRemoveBackchannelProviderHandler = (provider: Provider) => {
         return () => {
             const idx = this.backchannelProviders.indexOf(provider);
             this.backchannelProviders.splice(idx, 1);
             this.requestUpdate();
         };
-    }
+    };
 
     handleClearIcon(ev: Event) {
         ev.stopPropagation();
@@ -116,36 +127,40 @@ export class ApplicationForm extends WithCapabilitiesConfig(ModelForm<Applicatio
         this.clearIcon = !!(ev.target as HTMLInputElement).checked;
     }
 
-    renderForm(): TemplateResult {
+    public override renderForm(): TemplateResult {
         const alertMsg = msg(
             "Using this form will only create an Application. In order to authenticate with the application, you will have to manually pair it with a Provider.",
         );
 
-        return html`<form class="pf-c-form pf-m-horizontal">
+        return html`
             ${this.instance ? nothing : html`<ak-alert level="pf-m-info">${alertMsg}</ak-alert>`}
             <ak-text-input
                 name="name"
+                autocomplete="off"
+                placeholder=${msg("Application name")}
                 value=${ifDefined(this.instance?.name)}
                 label=${msg("Name")}
                 required
-                help=${msg("Application's display Name.")}
+                help=${msg("The name displayed in the application library.")}
             ></ak-text-input>
-            <ak-text-input
+            <ak-slug-input
                 name="slug"
+                autocomplete="off"
                 value=${ifDefined(this.instance?.slug)}
                 label=${msg("Slug")}
                 required
                 help=${msg("Internal application name used in URLs.")}
-                inputHint="code"
-            ></ak-text-input>
+                input-hint="code"
+            ></ak-slug-input>
             <ak-text-input
                 name="group"
                 value=${ifDefined(this.instance?.group)}
                 label=${msg("Group")}
+                placeholder=${msg("e.g. Collaboration, Communication, Internal, etc.")}
                 help=${msg(
                     "Optionally enter a group name. Applications with identical groups are shown grouped together.",
                 )}
-                inputHint="code"
+                input-hint="code"
             ></ak-text-input>
             <ak-provider-search-input
                 name="provider"
@@ -161,8 +176,8 @@ export class ApplicationForm extends WithCapabilitiesConfig(ModelForm<Applicatio
                     "Select backchannel providers which augment the functionality of the main provider.",
                 )}
                 .providers=${this.backchannelProviders}
-                .confirm=${this.handleConfirmBackchannelProviders}
-                .remover=${this.makeRemoveBackchannelProviderHandler}
+                .confirm=${this.#handleConfirmBackchannelProviders}
+                .remover=${this.#makeRemoveBackchannelProviderHandler}
                 .tooltip=${html`<pf-tooltip
                     position="top"
                     content=${msg("Add provider")}
@@ -173,20 +188,20 @@ export class ApplicationForm extends WithCapabilitiesConfig(ModelForm<Applicatio
                 label=${msg("Policy engine mode")}
                 required
                 name="policyEngineMode"
-                .options=${policyOptions}
+                .options=${policyEngineModes}
                 .value=${this.instance?.policyEngineMode}
             ></ak-radio-input>
-            <ak-form-group>
-                <span slot="header"> ${msg("UI settings")} </span>
-                <div slot="body" class="pf-c-form">
+            <ak-form-group label="${msg("UI settings")}">
+                <div class="pf-c-form">
                     <ak-text-input
                         name="metaLaunchUrl"
                         label=${msg("Launch URL")}
+                        placeholder="https://..."
                         value=${ifDefined(this.instance?.metaLaunchUrl)}
                         help=${msg(
                             "If left empty, authentik will try to extract the launch URL based on the selected provider.",
                         )}
-                        inputHint="code"
+                        input-hint="code"
                     ></ak-text-input>
                     <ak-switch-input
                         name="openInNewTab"
@@ -233,7 +248,7 @@ export class ApplicationForm extends WithCapabilitiesConfig(ModelForm<Applicatio
                     ></ak-textarea-input>
                 </div>
             </ak-form-group>
-        </form>`;
+        `;
     }
 }
 
