@@ -1,29 +1,30 @@
 import "#admin/applications/ApplicationForm";
-import { DEFAULT_CONFIG } from "#common/api/config";
 import "#elements/AppIcon";
 import "#elements/ak-mdx/ak-mdx";
 import "#elements/buttons/SpinnerButton/ak-spinner-button";
 import "#elements/forms/DeleteBulkForm";
 import "#elements/forms/ModalForm";
+import "@patternfly/elements/pf-tooltip/pf-tooltip.js";
+import "./ApplicationWizardHint.js";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+
 import { WithBrandConfig } from "#elements/mixins/branding";
 import { getURLParam } from "#elements/router/RouteMatch";
-import { PaginatedResponse } from "#elements/table/Table";
-import { TableColumn } from "#elements/table/Table";
+import { PaginatedResponse, TableColumn } from "#elements/table/Table";
 import { TablePage } from "#elements/table/TablePage";
-import "@patternfly/elements/pf-tooltip/pf-tooltip.js";
+
+import { Application, CoreApi, PoliciesApi } from "@goauthentik/api";
+
 import MDApplication from "~docs/add-secure-apps/applications/index.md";
 
 import { msg, str } from "@lit/localize";
-import { CSSResult, TemplateResult, css, html } from "lit";
+import { css, CSSResult, html, TemplateResult } from "lit";
 import { customElement, property } from "lit/decorators.js";
 import { ifDefined } from "lit/directives/if-defined.js";
 
 import PFCard from "@patternfly/patternfly/components/Card/card.css";
 
-import { Application, CoreApi, PoliciesApi } from "@goauthentik/api";
-
-import "./ApplicationWizardHint.js";
-
 export const applicationListStyle = css`
     /* Fix alignment issues with images in tables */
     .pf-c-table tbody > tr > * {
@@ -70,9 +71,7 @@ export class ApplicationListPage extends WithBrandConfig(TablePage<Application>)
         });
     }
 
-    static get styles(): CSSResult[] {
-        return TablePage.styles.concat(PFCard, applicationListStyle);
-    }
+    static styles: CSSResult[] = [...TablePage.styles, PFCard, applicationListStyle];
 
     columns(): TableColumn[] {
         return [
@@ -85,7 +84,7 @@ export class ApplicationListPage extends WithBrandConfig(TablePage<Application>)
         ];
     }
 
-    renderSidebarAfter(): TemplateResult {
+    protected renderSidebarAfter(): TemplateResult {
         return html`<div class="pf-c-sidebar__panel pf-m-width-25">
             <div class="pf-c-card">
                 <div class="pf-c-card__body">
