@@ -1,16 +1,18 @@
+import "#admin/applications/wizard/ak-wizard-title";
+
+import { ApplicationWizardProviderForm } from "./ApplicationWizardProviderForm.js";
+
 import { WithBrandConfig } from "#elements/mixins/branding";
-import "@goauthentik/admin/applications/wizard/ak-wizard-title.js";
-import { ValidationRecord } from "@goauthentik/admin/applications/wizard/types";
-import { renderForm } from "@goauthentik/admin/providers/radius/RadiusProviderFormForm.js";
+
+import { ValidationRecord } from "#admin/applications/wizard/types";
+import { renderForm } from "#admin/providers/radius/RadiusProviderFormForm";
+
+import { RadiusProvider } from "@goauthentik/api";
 
 import { msg } from "@lit/localize";
 import { customElement } from "@lit/reactive-element/decorators.js";
 import { html } from "lit";
 
-import { RadiusProvider } from "@goauthentik/api";
-
-import { ApplicationWizardProviderForm } from "./ApplicationWizardProviderForm.js";
-
 @customElement("ak-application-wizard-provider-for-radius")
 export class ApplicationWizardRadiusProviderForm extends WithBrandConfig(
     ApplicationWizardProviderForm<RadiusProvider>,
