@@ -1,8 +1,8 @@
-import { customElement, property } from "lit/decorators.js";
+import FlowSearch from "./FlowSearch.js";
 
 import type { Flow } from "@goauthentik/api";
 
-import FlowSearch from "./FlowSearch";
+import { customElement, property } from "lit/decorators.js";
 
 /**
  * Search for flows that may have a fallback specified by the brand settings
