@@ -1,9 +1,8 @@
-import { customElement } from "lit/decorators.js";
-import { property } from "lit/decorators.js";
+import FlowSearch from "./FlowSearch.js";
 
 import type { Flow } from "@goauthentik/api";
 
-import FlowSearch from "./FlowSearch";
+import { customElement, property } from "lit/decorators.js";
 
 /**
  * Search for flows that connect to user sources
