@@ -1,18 +1,20 @@
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import { SentryIgnoredError } from "@goauthentik/common/sentry";
-import "@goauthentik/components/ak-status-label";
-import "@goauthentik/elements/events/LogViewer";
-import { Form } from "@goauthentik/elements/forms/Form";
-import "@goauthentik/elements/forms/HorizontalFormElement";
+import "#components/ak-status-label";
+import "#elements/events/LogViewer";
+import "#elements/forms/HorizontalFormElement";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+import { SentryIgnoredError } from "#common/sentry/index";
+
+import { Form } from "#elements/forms/Form";
+
+import { Flow, FlowImportResult, FlowsApi } from "@goauthentik/api";
 
 import { msg } from "@lit/localize";
-import { CSSResult, TemplateResult, html } from "lit";
+import { CSSResult, html, TemplateResult } from "lit";
 import { customElement, state } from "lit/decorators.js";
 
 import PFDescriptionList from "@patternfly/patternfly/components/DescriptionList/description-list.css";
 
-import { Flow, FlowImportResult, FlowsApi } from "@goauthentik/api";
-
 @customElement("ak-flow-import-form")
 export class FlowImportForm extends Form<Flow> {
     @state()
@@ -22,12 +24,10 @@ export class FlowImportForm extends Form<Flow> {
         return msg("Successfully imported flow.");
     }
 
-    static get styles(): CSSResult[] {
-        return super.styles.concat(PFDescriptionList);
-    }
+    static styles: CSSResult[] = [...super.styles, PFDescriptionList];
 
     async send(): Promise<FlowImportResult> {
-        const file = this.getFormFiles().flow;
+        const file = this.files().get("flow");
         if (!file) {
             throw new SentryIgnoredError("No form data");
         }
