@@ -8,20 +8,22 @@ import "#admin/providers/radius/RadiusProviderViewPage";
 import "#admin/providers/saml/SAMLProviderViewPage";
 import "#admin/providers/scim/SCIMProviderViewPage";
 import "#admin/providers/ssf/SSFProviderViewPage";
-import { DEFAULT_CONFIG } from "#common/api/config";
 import "#components/ak-page-header";
-import { AKElement } from "#elements/Base";
 import "#elements/EmptyState";
 import "#elements/buttons/SpinnerButton/ak-spinner-button";
 
-import { CSSResult, TemplateResult, html } from "lit";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { AKElement } from "#elements/Base";
+
+import { Provider, ProvidersApi } from "@goauthentik/api";
+
+import { CSSResult, html, TemplateResult } from "lit";
 import { customElement, property } from "lit/decorators.js";
 import { ifDefined } from "lit/directives/if-defined.js";
 
 import PFPage from "@patternfly/patternfly/components/Page/page.css";
 
-import { Provider, ProvidersApi } from "@goauthentik/api";
-
 @customElement("ak-provider-view")
 export class ProviderViewPage extends AKElement {
     @property({ type: Number })
@@ -36,13 +38,11 @@ export class ProviderViewPage extends AKElement {
     @property({ attribute: false })
     provider?: Provider;
 
-    static get styles(): CSSResult[] {
-        return [PFPage];
-    }
+    static styles: CSSResult[] = [PFPage];
 
     renderProvider(): TemplateResult {
         if (!this.provider) {
-            return html`<ak-empty-state loading ?fullHeight=${true}></ak-empty-state>`;
+            return html`<ak-empty-state loading full-height></ak-empty-state>`;
         }
         switch (this.provider?.component) {
             case "ak-provider-saml-form":
