@@ -1,14 +1,17 @@
-import { WithBrandConfig } from "#elements/mixins/branding";
-import "@goauthentik/admin/common/ak-crypto-certificate-search";
-import "@goauthentik/admin/common/ak-flow-search/ak-branded-flow-search";
-import { BaseProviderForm } from "@goauthentik/admin/providers/BaseProviderForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
+import "#admin/common/ak-crypto-certificate-search";
+import "#admin/common/ak-flow-search/ak-branded-flow-search";
 
-import { customElement } from "lit/decorators.js";
+import { renderForm } from "./LDAPProviderFormForm.js";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { WithBrandConfig } from "#elements/mixins/branding";
+
+import { BaseProviderForm } from "#admin/providers/BaseProviderForm";
 
 import { LDAPProvider, ProvidersApi } from "@goauthentik/api";
 
-import { renderForm } from "./LDAPProviderFormForm.js";
+import { customElement } from "lit/decorators.js";
 
 @customElement("ak-provider-ldap-form")
 export class LDAPProviderFormPage extends WithBrandConfig(BaseProviderForm<LDAPProvider>) {
