@@ -1,13 +1,15 @@
-import { BaseProviderForm } from "@goauthentik/admin/providers/BaseProviderForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import { DualSelectPair } from "@goauthentik/elements/ak-dual-select/types";
+import { renderForm } from "./OAuth2ProviderFormForm.js";
 
-import { css } from "lit";
-import { customElement, state } from "lit/decorators.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { DualSelectPair } from "#elements/ak-dual-select/types";
+
+import { BaseProviderForm } from "#admin/providers/BaseProviderForm";
 
 import { ClientTypeEnum, OAuth2Provider, ProvidersApi } from "@goauthentik/api";
 
-import { renderForm } from "./OAuth2ProviderFormForm.js";
+import { css } from "lit";
+import { customElement, state } from "lit/decorators.js";
 
 const providerToSelect = (provider: OAuth2Provider) => [provider.pk, provider.name];
 
@@ -60,13 +62,14 @@ export class OAuth2ProviderFormPage extends BaseProviderForm<OAuth2Provider> {
     @state()
     showClientSecret = true;
 
-    static get styles() {
-        return super.styles.concat(css`
+    static styles = [
+        ...super.styles,
+        css`
             ak-array-input {
                 width: 100%;
             }
-        `);
-    }
+        `,
+    ];
 
     async loadInstance(pk: number): Promise<OAuth2Provider> {
         const provider = await new ProvidersApi(DEFAULT_CONFIG).providersOauth2Retrieve({
