@@ -1,12 +1,14 @@
-import { WithBrandConfig } from "#elements/mixins/branding";
-import { BaseProviderForm } from "@goauthentik/admin/providers/BaseProviderForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
+import { renderForm } from "./RadiusProviderFormForm.js";
 
-import { customElement } from "lit/decorators.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { WithBrandConfig } from "#elements/mixins/branding";
+
+import { BaseProviderForm } from "#admin/providers/BaseProviderForm";
 
 import { ProvidersApi, RadiusProvider } from "@goauthentik/api";
 
-import { renderForm } from "./RadiusProviderFormForm.js";
+import { customElement } from "lit/decorators.js";
 
 @customElement("ak-provider-radius-form")
 export class RadiusProviderFormPage extends WithBrandConfig(BaseProviderForm<RadiusProvider>) {
