@@ -1,11 +1,12 @@
-import { BaseProviderForm } from "@goauthentik/admin/providers/BaseProviderForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
+import { renderForm } from "./SCIMProviderFormForm.js";
 
-import { customElement } from "lit/decorators.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { BaseProviderForm } from "#admin/providers/BaseProviderForm";
 
 import { ProvidersApi, SCIMProvider } from "@goauthentik/api";
 
-import { renderForm } from "./SCIMProviderFormForm.js";
+import { customElement } from "lit/decorators.js";
 
 @customElement("ak-provider-scim-form")
 export class SCIMProviderFormPage extends BaseProviderForm<SCIMProvider> {
