@@ -1,16 +1,21 @@
 import "#admin/groups/RelatedGroupList";
 import "#admin/rbac/ObjectPermissionsPage";
 import "#admin/roles/RoleForm";
-import { DEFAULT_CONFIG } from "#common/api/config";
-import { EVENT_REFRESH } from "#common/constants";
-import { renderDescriptionList } from "#components/DescriptionList";
 import "#components/ak-page-header";
 import "#components/events/ObjectChangelog";
 import "#components/events/UserEvents";
-import { AKElement } from "#elements/Base";
 import "#elements/Tabs";
 import "#elements/forms/ModalForm";
 
+import { DEFAULT_CONFIG } from "#common/api/config";
+import { EVENT_REFRESH } from "#common/constants";
+
+import { AKElement } from "#elements/Base";
+
+import { renderDescriptionList } from "#components/DescriptionList";
+
+import { RbacApi, RbacPermissionsAssignedByUsersListModelEnum, Role } from "@goauthentik/api";
+
 import { msg, str } from "@lit/localize";
 import { css, html, nothing } from "lit";
 import { customElement, property, state } from "lit/decorators.js";
@@ -24,8 +29,6 @@ import PFGrid from "@patternfly/patternfly/layouts/Grid/grid.css";
 import PFBase from "@patternfly/patternfly/patternfly-base.css";
 import PFDisplay from "@patternfly/patternfly/utilities/Display/display.css";
 
-import { RbacApi, RbacPermissionsAssignedByUsersListModelEnum, Role } from "@goauthentik/api";
-
 @customElement("ak-role-view")
 export class RoleViewPage extends AKElement {
     @property({ type: String })
@@ -42,27 +45,25 @@ export class RoleViewPage extends AKElement {
     @state()
     _role?: Role;
 
-    static get styles() {
-        return [
-            PFBase,
-            PFPage,
-            PFButton,
-            PFDisplay,
-            PFGrid,
-            PFContent,
-            PFCard,
-            PFDescriptionList,
-            css`
-                .pf-c-description-list__description ak-action-button {
-                    margin-right: 6px;
-                    margin-bottom: 6px;
-                }
-                .ak-button-collection {
-                    max-width: 12em;
-                }
-            `,
-        ];
-    }
+    static styles = [
+        PFBase,
+        PFPage,
+        PFButton,
+        PFDisplay,
+        PFGrid,
+        PFContent,
+        PFCard,
+        PFDescriptionList,
+        css`
+            .pf-c-description-list__description ak-action-button {
+                margin-right: 6px;
+                margin-bottom: 6px;
+            }
+            .ak-button-collection {
+                max-width: 12em;
+            }
+        `,
+    ];
 
     constructor() {
         super();
