@@ -4,18 +4,20 @@ import "#admin/sources/oauth/OAuthSourceViewPage";
 import "#admin/sources/plex/PlexSourceViewPage";
 import "#admin/sources/saml/SAMLSourceViewPage";
 import "#admin/sources/scim/SCIMSourceViewPage";
-import { DEFAULT_CONFIG } from "#common/api/config";
 import "#components/ak-page-header";
-import { AKElement } from "#elements/Base";
 import "#elements/EmptyState";
 import "#elements/buttons/SpinnerButton/ak-spinner-button";
 
-import { TemplateResult, html } from "lit";
-import { customElement, property } from "lit/decorators.js";
-import { ifDefined } from "lit/directives/if-defined.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { AKElement } from "#elements/Base";
 
 import { Source, SourcesApi } from "@goauthentik/api";
 
+import { html, TemplateResult } from "lit";
+import { customElement, property } from "lit/decorators.js";
+import { ifDefined } from "lit/directives/if-defined.js";
+
 @customElement("ak-source-view")
 export class SourceViewPage extends AKElement {
     @property({ type: String })
@@ -34,7 +36,7 @@ export class SourceViewPage extends AKElement {
 
     renderSource(): TemplateResult {
         if (!this.source) {
-            return html`<ak-empty-state loading ?fullHeight=${true}></ak-empty-state>`;
+            return html`<ak-empty-state loading full-height></ak-empty-state>`;
         }
         switch (this.source?.component) {
             case "ak-source-kerberos-form":
