@@ -1,7 +1,8 @@
-import { AKElement } from "@goauthentik/elements/Base";
 import "@patternfly/elements/pf-tooltip/pf-tooltip.js";
 
-import { CSSResult, TemplateResult, html } from "lit";
+import { AKElement } from "#elements/Base";
+
+import { CSSResult, html, TemplateResult } from "lit";
 import { customElement, property } from "lit/decorators.js";
 
 import PFList from "@patternfly/patternfly/components/List/list.css";
@@ -16,9 +17,7 @@ export class KerberosSourceConnectivity extends AKElement {
         };
     };
 
-    static get styles(): CSSResult[] {
-        return [PFBase, PFList];
-    }
+    static styles: CSSResult[] = [PFBase, PFList];
 
     render(): TemplateResult {
         if (!this.connectivity) {
