@@ -1,22 +1,32 @@
-import "@goauthentik/admin/rbac/ObjectPermissionsPage";
-import "@goauthentik/admin/sources/kerberos/KerberosSourceConnectivity";
-import "@goauthentik/admin/sources/kerberos/KerberosSourceForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import { EVENT_REFRESH } from "@goauthentik/common/constants";
-import "@goauthentik/components/events/ObjectChangelog";
-import { AKElement } from "@goauthentik/elements/Base";
-import "@goauthentik/elements/CodeMirror";
-import "@goauthentik/elements/Tabs";
-import "@goauthentik/elements/ak-mdx";
-import "@goauthentik/elements/buttons/ActionButton";
-import "@goauthentik/elements/buttons/SpinnerButton";
-import "@goauthentik/elements/forms/ModalForm";
-import "@goauthentik/elements/sync/SyncStatusCard";
+import "#admin/rbac/ObjectPermissionsPage";
+import "#admin/sources/kerberos/KerberosSourceConnectivity";
+import "#admin/sources/kerberos/KerberosSourceForm";
+import "#components/events/ObjectChangelog";
+import "#elements/CodeMirror";
+import "#elements/Tabs";
+import "#elements/ak-mdx/index";
+import "#elements/buttons/ActionButton/index";
+import "#elements/buttons/SpinnerButton/index";
+import "#elements/forms/ModalForm";
+import "#elements/sync/SyncStatusCard";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+import { EVENT_REFRESH } from "#common/constants";
+
+import { AKElement } from "#elements/Base";
+
+import {
+    KerberosSource,
+    ModelEnum,
+    RbacPermissionsAssignedByUsersListModelEnum,
+    SourcesApi,
+} from "@goauthentik/api";
+
 import MDSourceKerberosBrowser from "~docs/users-sources/sources/protocols/kerberos/browser.md";
 
 import { msg } from "@lit/localize";
-import { CSSResult, TemplateResult, html } from "lit";
-import { customElement, property, state } from "lit/decorators.js";
+import { CSSResult, html, TemplateResult } from "lit";
+import { customElement, property } from "lit/decorators.js";
 
 import PFBanner from "@patternfly/patternfly/components/Banner/banner.css";
 import PFButton from "@patternfly/patternfly/components/Button/button.css";
@@ -28,13 +38,6 @@ import PFPage from "@patternfly/patternfly/components/Page/page.css";
 import PFGrid from "@patternfly/patternfly/layouts/Grid/grid.css";
 import PFBase from "@patternfly/patternfly/patternfly-base.css";
 
-import {
-    KerberosSource,
-    RbacPermissionsAssignedByUsersListModelEnum,
-    SourcesApi,
-    SyncStatus,
-} from "@goauthentik/api";
-
 @customElement("ak-source-kerberos-view")
 export class KerberosSourceViewPage extends AKElement {
     @property({ type: String })
@@ -51,22 +54,17 @@ export class KerberosSourceViewPage extends AKElement {
     @property({ attribute: false })
     source!: KerberosSource;
 
-    @state()
-    syncState?: SyncStatus;
-
-    static get styles(): CSSResult[] {
-        return [
-            PFBase,
-            PFPage,
-            PFButton,
-            PFGrid,
-            PFContent,
-            PFCard,
-            PFDescriptionList,
-            PFBanner,
-            PFList,
-        ];
-    }
+    static styles: CSSResult[] = [
+        PFBase,
+        PFPage,
+        PFButton,
+        PFGrid,
+        PFContent,
+        PFCard,
+        PFDescriptionList,
+        PFBanner,
+        PFList,
+    ];
 
     constructor() {
         super();
@@ -76,61 +74,16 @@ export class KerberosSourceViewPage extends AKElement {
         });
     }
 
-    load(): void {
-        new SourcesApi(DEFAULT_CONFIG)
-            .sourcesKerberosSyncStatusRetrieve({
-                slug: this.source.slug,
-            })
-            .then((state) => {
-                this.syncState = state;
-            });
-    }
-
-    renderSyncCards(): TemplateResult {
-        if (!this.source.syncUsers) {
-            return html``;
-        }
-        return html`
-            <div class="pf-c-card pf-l-grid__item pf-m-2-col">
-                <div class="pf-c-card__title">
-                    <p>${msg("Connectivity")}</p>
-                </div>
-                <div class="pf-c-card__body">
-                    <ak-source-kerberos-connectivity
-                        .connectivity=${this.source.connectivity}
-                    ></ak-source-kerberos-connectivity>
-                </div>
-            </div>
-            <div class="pf-l-grid__item pf-m-10-col">
-                <ak-sync-status-card
-                    .fetch=${() => {
-                        return new SourcesApi(DEFAULT_CONFIG).sourcesKerberosSyncStatusRetrieve({
-                            slug: this.source?.slug,
-                        });
-                    }}
-                    .triggerSync=${() => {
-                        return new SourcesApi(DEFAULT_CONFIG).sourcesKerberosPartialUpdate({
-                            slug: this.source?.slug || "",
-                            patchedKerberosSourceRequest: {},
-                        });
-                    }}
-                ></ak-sync-status-card>
-            </div>
-        `;
-    }
-
     render(): TemplateResult {
         if (!this.source) {
             return html``;
         }
+        const [appLabel, modelName] = ModelEnum.AuthentikSourcesKerberosKerberossource.split(".");
         return html`<ak-tabs>
             <section
                 slot="page-overview"
                 data-tab-title="${msg("Overview")}"
                 class="pf-c-page__main-section pf-m-no-padding-mobile"
-                @activate=${() => {
-                    this.load();
-                }}
             >
                 <div slot="header" class="pf-c-banner pf-m-info">
                     ${msg("Kerberos Source is in preview.")}
@@ -139,7 +92,9 @@ export class KerberosSourceViewPage extends AKElement {
                     >
                 </div>
                 <div class="pf-l-grid pf-m-gutter">
-                    <div class="pf-c-card pf-l-grid__item pf-m-12-col">
+                    <div
+                        class="pf-c-card pf-l-grid__item pf-m-12-col pf-m-6-col-on-xl pf-m-6-col-on-2xl"
+                    >
                         <div class="pf-c-card__body">
                             <dl class="pf-c-description-list pf-m-2-col-on-lg">
                                 <div class="pf-c-description-list__group">
@@ -183,7 +138,41 @@ export class KerberosSourceViewPage extends AKElement {
                             </ak-forms-modal>
                         </div>
                     </div>
-                    ${this.renderSyncCards()}
+                    <div
+                        class="pf-c-card pf-l-grid__item pf-m-12-col pf-m-6-col-on-xl pf-m-6-col-on-2xl"
+                    >
+                        <ak-sync-status-card
+                            .fetch=${() => {
+                                return new SourcesApi(
+                                    DEFAULT_CONFIG,
+                                ).sourcesKerberosSyncStatusRetrieve({
+                                    slug: this.source?.slug,
+                                });
+                            }}
+                        ></ak-sync-status-card>
+                    </div>
+                    <div class="pf-c-card pf-l-grid__item pf-m-12-col">
+                        <div class="pf-c-card__title">
+                            <p>${msg("Connectivity")}</p>
+                        </div>
+                        <div class="pf-c-card__body">
+                            <ak-source-kerberos-connectivity
+                                .connectivity=${this.source.connectivity}
+                            ></ak-source-kerberos-connectivity>
+                        </div>
+                    </div>
+                    <div class="pf-c-card pf-l-grid__item pf-m-12-col">
+                        <div class="pf-c-card__title">
+                            <p>${msg("Schedules")}</p>
+                        </div>
+                        <div class="pf-c-card__body">
+                            <ak-schedule-list
+                                .relObjAppLabel=${appLabel}
+                                .relObjModel=${modelName}
+                                .relObjId="${this.source.pk}"
+                            ></ak-schedule-list>
+                        </div>
+                    </div>
                     <div class="pf-c-card pf-l-grid__item pf-m-12-col">
                         <div class="pf-c-card__body">
                             <ak-mdx .url=${MDSourceKerberosBrowser}></ak-mdx>
