@@ -1,45 +1,47 @@
-import "@goauthentik/admin/rbac/ObjectPermissionModal";
-import "@goauthentik/admin/stages/StageWizard";
-import "@goauthentik/admin/stages/authenticator_duo/AuthenticatorDuoStageForm";
-import "@goauthentik/admin/stages/authenticator_duo/DuoDeviceImportForm";
-import "@goauthentik/admin/stages/authenticator_email/AuthenticatorEmailStageForm";
-import "@goauthentik/admin/stages/authenticator_endpoint_gdtc/AuthenticatorEndpointGDTCStageForm";
-import "@goauthentik/admin/stages/authenticator_sms/AuthenticatorSMSStageForm";
-import "@goauthentik/admin/stages/authenticator_static/AuthenticatorStaticStageForm";
-import "@goauthentik/admin/stages/authenticator_totp/AuthenticatorTOTPStageForm";
-import "@goauthentik/admin/stages/authenticator_validate/AuthenticatorValidateStageForm";
-import "@goauthentik/admin/stages/authenticator_webauthn/AuthenticatorWebAuthnStageForm";
-import "@goauthentik/admin/stages/captcha/CaptchaStageForm";
-import "@goauthentik/admin/stages/consent/ConsentStageForm";
-import "@goauthentik/admin/stages/deny/DenyStageForm";
-import "@goauthentik/admin/stages/dummy/DummyStageForm";
-import "@goauthentik/admin/stages/email/EmailStageForm";
-import "@goauthentik/admin/stages/identification/IdentificationStageForm";
-import "@goauthentik/admin/stages/invitation/InvitationStageForm";
-import "@goauthentik/admin/stages/mtls/MTLSStageForm";
-import "@goauthentik/admin/stages/password/PasswordStageForm";
-import "@goauthentik/admin/stages/prompt/PromptStageForm";
-import "@goauthentik/admin/stages/redirect/RedirectStageForm";
-import "@goauthentik/admin/stages/source/SourceStageForm";
-import "@goauthentik/admin/stages/user_delete/UserDeleteStageForm";
-import "@goauthentik/admin/stages/user_login/UserLoginStageForm";
-import "@goauthentik/admin/stages/user_logout/UserLogoutStageForm";
-import "@goauthentik/admin/stages/user_write/UserWriteStageForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import "@goauthentik/elements/forms/DeleteBulkForm";
-import "@goauthentik/elements/forms/ModalForm";
-import "@goauthentik/elements/forms/ProxyForm";
-import { PaginatedResponse, TableColumn } from "@goauthentik/elements/table/Table";
-import { TablePage } from "@goauthentik/elements/table/TablePage";
+import "#admin/rbac/ObjectPermissionModal";
+import "#admin/stages/StageWizard";
+import "#admin/stages/authenticator_duo/AuthenticatorDuoStageForm";
+import "#admin/stages/authenticator_duo/DuoDeviceImportForm";
+import "#admin/stages/authenticator_email/AuthenticatorEmailStageForm";
+import "#admin/stages/authenticator_endpoint_gdtc/AuthenticatorEndpointGDTCStageForm";
+import "#admin/stages/authenticator_sms/AuthenticatorSMSStageForm";
+import "#admin/stages/authenticator_static/AuthenticatorStaticStageForm";
+import "#admin/stages/authenticator_totp/AuthenticatorTOTPStageForm";
+import "#admin/stages/authenticator_validate/AuthenticatorValidateStageForm";
+import "#admin/stages/authenticator_webauthn/AuthenticatorWebAuthnStageForm";
+import "#admin/stages/captcha/CaptchaStageForm";
+import "#admin/stages/consent/ConsentStageForm";
+import "#admin/stages/deny/DenyStageForm";
+import "#admin/stages/dummy/DummyStageForm";
+import "#admin/stages/email/EmailStageForm";
+import "#admin/stages/identification/IdentificationStageForm";
+import "#admin/stages/invitation/InvitationStageForm";
+import "#admin/stages/mtls/MTLSStageForm";
+import "#admin/stages/password/PasswordStageForm";
+import "#admin/stages/prompt/PromptStageForm";
+import "#admin/stages/redirect/RedirectStageForm";
+import "#admin/stages/source/SourceStageForm";
+import "#admin/stages/user_delete/UserDeleteStageForm";
+import "#admin/stages/user_login/UserLoginStageForm";
+import "#admin/stages/user_logout/UserLogoutStageForm";
+import "#admin/stages/user_write/UserWriteStageForm";
+import "#elements/forms/DeleteBulkForm";
+import "#elements/forms/ModalForm";
+import "#elements/forms/ProxyForm";
 import "@patternfly/elements/pf-tooltip/pf-tooltip.js";
 
-import { msg, str } from "@lit/localize";
-import { TemplateResult, html, nothing } from "lit";
-import { customElement, property } from "lit/decorators.js";
-import { ifDefined } from "lit/directives/if-defined.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { PaginatedResponse, TableColumn } from "#elements/table/Table";
+import { TablePage } from "#elements/table/TablePage";
 
 import { Stage, StagesApi } from "@goauthentik/api";
 
+import { msg, str } from "@lit/localize";
+import { html, nothing, TemplateResult } from "lit";
+import { customElement, property } from "lit/decorators.js";
+import { ifDefined } from "lit/directives/if-defined.js";
+
 @customElement("ak-stage-list")
 export class StageListPage extends TablePage<Stage> {
     pageTitle(): string {
