@@ -1,52 +1,53 @@
-import "@goauthentik/admin/common/ak-license-notice";
-import { StageBindingForm } from "@goauthentik/admin/flows/StageBindingForm";
-import "@goauthentik/admin/stages/authenticator_duo/AuthenticatorDuoStageForm";
-import "@goauthentik/admin/stages/authenticator_email/AuthenticatorEmailStageForm";
-import "@goauthentik/admin/stages/authenticator_sms/AuthenticatorSMSStageForm";
-import "@goauthentik/admin/stages/authenticator_static/AuthenticatorStaticStageForm";
-import "@goauthentik/admin/stages/authenticator_totp/AuthenticatorTOTPStageForm";
-import "@goauthentik/admin/stages/authenticator_validate/AuthenticatorValidateStageForm";
-import "@goauthentik/admin/stages/authenticator_webauthn/AuthenticatorWebAuthnStageForm";
-import "@goauthentik/admin/stages/captcha/CaptchaStageForm";
-import "@goauthentik/admin/stages/consent/ConsentStageForm";
-import "@goauthentik/admin/stages/deny/DenyStageForm";
-import "@goauthentik/admin/stages/dummy/DummyStageForm";
-import "@goauthentik/admin/stages/email/EmailStageForm";
-import "@goauthentik/admin/stages/identification/IdentificationStageForm";
-import "@goauthentik/admin/stages/invitation/InvitationStageForm";
-import "@goauthentik/admin/stages/mtls/MTLSStageForm";
-import "@goauthentik/admin/stages/password/PasswordStageForm";
-import "@goauthentik/admin/stages/prompt/PromptStageForm";
-import "@goauthentik/admin/stages/redirect/RedirectStageForm";
-import "@goauthentik/admin/stages/source/SourceStageForm";
-import "@goauthentik/admin/stages/user_delete/UserDeleteStageForm";
-import "@goauthentik/admin/stages/user_login/UserLoginStageForm";
-import "@goauthentik/admin/stages/user_logout/UserLogoutStageForm";
-import "@goauthentik/admin/stages/user_write/UserWriteStageForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import { AKElement } from "@goauthentik/elements/Base";
-import "@goauthentik/elements/forms/ProxyForm";
-import "@goauthentik/elements/wizard/FormWizardPage";
-import { FormWizardPage } from "@goauthentik/elements/wizard/FormWizardPage";
-import "@goauthentik/elements/wizard/TypeCreateWizardPage";
-import "@goauthentik/elements/wizard/Wizard";
-import { Wizard } from "@goauthentik/elements/wizard/Wizard";
+import "#admin/common/ak-license-notice";
+import "#admin/stages/authenticator_duo/AuthenticatorDuoStageForm";
+import "#admin/stages/authenticator_email/AuthenticatorEmailStageForm";
+import "#admin/stages/authenticator_sms/AuthenticatorSMSStageForm";
+import "#admin/stages/authenticator_static/AuthenticatorStaticStageForm";
+import "#admin/stages/authenticator_totp/AuthenticatorTOTPStageForm";
+import "#admin/stages/authenticator_validate/AuthenticatorValidateStageForm";
+import "#admin/stages/authenticator_webauthn/AuthenticatorWebAuthnStageForm";
+import "#admin/stages/captcha/CaptchaStageForm";
+import "#admin/stages/consent/ConsentStageForm";
+import "#admin/stages/deny/DenyStageForm";
+import "#admin/stages/dummy/DummyStageForm";
+import "#admin/stages/email/EmailStageForm";
+import "#admin/stages/identification/IdentificationStageForm";
+import "#admin/stages/invitation/InvitationStageForm";
+import "#admin/stages/mtls/MTLSStageForm";
+import "#admin/stages/password/PasswordStageForm";
+import "#admin/stages/prompt/PromptStageForm";
+import "#admin/stages/redirect/RedirectStageForm";
+import "#admin/stages/source/SourceStageForm";
+import "#admin/stages/user_delete/UserDeleteStageForm";
+import "#admin/stages/user_login/UserLoginStageForm";
+import "#admin/stages/user_logout/UserLogoutStageForm";
+import "#admin/stages/user_write/UserWriteStageForm";
+import "#elements/forms/ProxyForm";
+import "#elements/wizard/FormWizardPage";
+import "#elements/wizard/TypeCreateWizardPage";
+import "#elements/wizard/Wizard";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { AKElement } from "#elements/Base";
+import { FormWizardPage } from "#elements/wizard/FormWizardPage";
+import { Wizard } from "#elements/wizard/Wizard";
+
+import { StageBindingForm } from "#admin/flows/StageBindingForm";
+
+import { FlowStageBinding, Stage, StagesApi, TypeCreate } from "@goauthentik/api";
 
 import { msg, str } from "@lit/localize";
 import { customElement } from "@lit/reactive-element/decorators/custom-element.js";
-import { CSSResult, TemplateResult, html } from "lit";
+import { CSSResult, html, TemplateResult } from "lit";
 import { property, query } from "lit/decorators.js";
 
 import PFButton from "@patternfly/patternfly/components/Button/button.css";
 import PFBase from "@patternfly/patternfly/patternfly-base.css";
 
-import { FlowStageBinding, Stage, StagesApi, TypeCreate } from "@goauthentik/api";
-
 @customElement("ak-stage-wizard")
 export class StageWizard extends AKElement {
-    static get styles(): CSSResult[] {
-        return [PFBase, PFButton];
-    }
+    static styles: CSSResult[] = [PFBase, PFButton];
 
     @property()
     createText = msg("Create");
