@@ -1,18 +1,21 @@
-import { BaseStageForm } from "@goauthentik/admin/stages/BaseStageForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import "@goauthentik/elements/CodeMirror";
-import { CodeMirrorMode } from "@goauthentik/elements/CodeMirror";
-import "@goauthentik/elements/forms/FormGroup";
-import "@goauthentik/elements/forms/HorizontalFormElement";
+import "#elements/CodeMirror";
+import "#elements/forms/FormGroup";
+import "#elements/forms/HorizontalFormElement";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { CodeMirrorMode } from "#elements/CodeMirror";
+
+import { BaseStageForm } from "#admin/stages/BaseStageForm";
+
+import { AuthenticatorEndpointGDTCStage, StagesApi } from "@goauthentik/api";
 
 import { msg } from "@lit/localize";
-import { TemplateResult, html } from "lit";
+import { html, TemplateResult } from "lit";
 import { customElement } from "lit/decorators.js";
 
 import PFBanner from "@patternfly/patternfly/components/Banner/banner.css";
 
-import { AuthenticatorEndpointGDTCStage, StagesApi } from "@goauthentik/api";
-
 @customElement("ak-stage-authenticator-endpoint-gdtc-form")
 export class AuthenticatorEndpointGDTCStageForm extends BaseStageForm<AuthenticatorEndpointGDTCStage> {
     loadInstance(pk: string): Promise<AuthenticatorEndpointGDTCStage> {
@@ -33,9 +36,7 @@ export class AuthenticatorEndpointGDTCStageForm extends BaseStageForm<Authentica
         });
     }
 
-    static get styles() {
-        return super.styles.concat(PFBanner);
-    }
+    static styles = [...super.styles, PFBanner];
 
     renderForm(): TemplateResult {
         return html`<div class="pf-c-banner pf-m-info">
@@ -55,9 +56,8 @@ export class AuthenticatorEndpointGDTCStageForm extends BaseStageForm<Authentica
                     required
                 />
             </ak-form-element-horizontal>
-            <ak-form-group expanded>
-                <span slot="header"> ${msg("Google Verified Access API")} </span>
-                <div slot="body" class="pf-c-form">
+            <ak-form-group open label="${msg("Google Verified Access API")}">
+                <div class="pf-c-form">
                     <ak-form-element-horizontal
                         label=${msg("Credentials")}
                         required
