@@ -1,17 +1,20 @@
-import { BaseStageForm } from "@goauthentik/admin/stages/BaseStageForm";
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import "@goauthentik/components/ak-number-input";
-import "@goauthentik/components/ak-switch-input";
-import "@goauthentik/elements/forms/FormGroup";
-import "@goauthentik/elements/forms/HorizontalFormElement";
+import "#components/ak-number-input";
+import "#components/ak-secret-text-input";
+import "#components/ak-switch-input";
+import "#elements/forms/FormGroup";
+import "#elements/forms/HorizontalFormElement";
 
-import { msg } from "@lit/localize";
-import { TemplateResult, html } from "lit";
-import { customElement } from "lit/decorators.js";
-import { ifDefined } from "lit/directives/if-defined.js";
+import { DEFAULT_CONFIG } from "#common/api/config";
+
+import { BaseStageForm } from "#admin/stages/BaseStageForm";
 
 import { CaptchaStage, CaptchaStageRequest, StagesApi } from "@goauthentik/api";
 
+import { msg } from "@lit/localize";
+import { html, TemplateResult } from "lit";
+import { customElement } from "lit/decorators.js";
+import { ifDefined } from "lit/directives/if-defined.js";
+
 @customElement("ak-stage-captcha-form")
 export class CaptchaStageForm extends BaseStageForm<CaptchaStage> {
     loadInstance(pk: string): Promise<CaptchaStage> {
@@ -38,7 +41,7 @@ export class CaptchaStageForm extends BaseStageForm<CaptchaStage> {
                     "This stage checks the user's current session against the Google reCaptcha (or compatible) service.",
                 )}
             </span>
-            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
+            <ak-form-element-horizontal label=${msg("Name")} required name="name">
                 <input
                     type="text"
                     value="${ifDefined(this.instance?.name || "")}"
@@ -46,12 +49,11 @@ export class CaptchaStageForm extends BaseStageForm<CaptchaStage> {
                     required
                 />
             </ak-form-element-horizontal>
-            <ak-form-group .expanded=${true}>
-                <span slot="header"> ${msg("Stage-specific settings")} </span>
-                <div slot="body" class="pf-c-form">
+            <ak-form-group open label="${msg("Stage-specific settings")}">
+                <div class="pf-c-form">
                     <ak-form-element-horizontal
                         label=${msg("Public Key")}
-                        ?required=${true}
+                        required
                         name="publicKey"
                     >
                         <input
@@ -68,26 +70,18 @@ export class CaptchaStageForm extends BaseStageForm<CaptchaStage> {
                             )}
                         </p>
                     </ak-form-element-horizontal>
-                    <ak-form-element-horizontal
-                        label=${msg("Private Key")}
-                        ?required=${true}
-                        ?writeOnly=${this.instance !== undefined}
+
+                    <ak-secret-text-input
                         name="privateKey"
-                    >
-                        <input
-                            type="text"
-                            value=""
-                            class="pf-c-form-control pf-m-monospace"
-                            autocomplete="off"
-                            spellcheck="false"
-                            required
-                        />
-                        <p class="pf-c-form__helper-text">
-                            ${msg(
-                                "Private key, acquired from https://www.google.com/recaptcha/intro/v3.html.",
-                            )}
-                        </p>
-                    </ak-form-element-horizontal>
+                        label=${msg("Private Key")}
+                        input-hint="code"
+                        ?required=${!this.instance}
+                        ?revealed=${!this.instance}
+                        help=${msg(
+                            "Private key, acquired from https://www.google.com/recaptcha/intro/v3.html.",
+                        )}
+                    ></ak-secret-text-input>
+
                     <ak-switch-input
                         name="interactive"
                         label=${msg("Interactive")}
@@ -111,36 +105,19 @@ export class CaptchaStageForm extends BaseStageForm<CaptchaStage> {
                         value="${ifDefined(this.instance?.scoreMaxThreshold || -1)}"
                         help=${msg("Maximum allowed score to allow continuing")}
                     ></ak-number-input>
-                    <ak-form-element-horizontal name="errorOnInvalidScore">
-                        <label class="pf-c-switch">
-                            <input
-                                class="pf-c-switch__input"
-                                type="checkbox"
-                                ?checked=${this.instance?.errorOnInvalidScore ?? true}
-                            />
-                            <span class="pf-c-switch__toggle">
-                                <span class="pf-c-switch__toggle-icon">
-                                    <i class="fas fa-check" aria-hidden="true"></i>
-                                </span>
-                            </span>
-                            <span class="pf-c-switch__label">${msg("Error on invalid score")}</span>
-                        </label>
-                        <p class="pf-c-form__helper-text">
-                            ${msg(
-                                "When enabled and the resultant score is outside the threshold, the user will not be able to continue. When disabled, the user will be able to continue and the score can be used in policies to customize further stages.",
-                            )}
-                        </p>
-                    </ak-form-element-horizontal>
+                    <ak-switch-input
+                        ?checked=${!!(this.instance?.errorOnInvalidScore ?? true)}
+                        name="errorOnInvalidScore"
+                        label=${msg("Error on invalid score")}
+                        help=${msg(
+                            "When enabled and the resultant score is outside the threshold, the user will not be able to continue. When disabled, the user will be able to continue and the score can be used in policies to customize further stages.",
+                        )}
+                    ></ak-switch-input>
                 </div>
             </ak-form-group>
-            <ak-form-group>
-                <span slot="header"> ${msg("Advanced settings")} </span>
-                <div slot="body" class="pf-c-form">
-                    <ak-form-element-horizontal
-                        label=${msg("JS URL")}
-                        ?required=${true}
-                        name="jsUrl"
-                    >
+            <ak-form-group label="${msg("Advanced settings")}">
+                <div class="pf-c-form">
+                    <ak-form-element-horizontal label=${msg("JS URL")} required name="jsUrl">
                         <input
                             type="url"
                             value="${ifDefined(
@@ -158,11 +135,7 @@ export class CaptchaStageForm extends BaseStageForm<CaptchaStage> {
                             )}
                         </p>
                     </ak-form-element-horizontal>
-                    <ak-form-element-horizontal
-                        label=${msg("API URL")}
-                        ?required=${true}
-                        name="apiUrl"
-                    >
+                    <ak-form-element-horizontal label=${msg("API URL")} required name="apiUrl">
                         <input
                             type="url"
                             value="${ifDefined(
