@@ -1,14 +1,25 @@
-import { DEFAULT_CONFIG } from "@goauthentik/common/api/config";
-import { parseAPIResponseError, pluckErrorDetail } from "@goauthentik/common/errors/network";
-import "@goauthentik/elements/CodeMirror";
-import { CodeMirrorMode } from "@goauthentik/elements/CodeMirror";
-import "@goauthentik/elements/forms/HorizontalFormElement";
-import { ModelForm } from "@goauthentik/elements/forms/ModelForm";
-import { StageHost } from "@goauthentik/flow/stages/base";
-import "@goauthentik/flow/stages/prompt/PromptStage";
+import "#elements/CodeMirror";
+import "#elements/forms/HorizontalFormElement";
+import "#flow/stages/prompt/PromptStage";
+
+import { DEFAULT_CONFIG } from "#common/api/config";
+import { parseAPIResponseError, pluckErrorDetail } from "#common/errors/network";
+
+import { CodeMirrorMode } from "#elements/CodeMirror";
+import { ModelForm } from "#elements/forms/ModelForm";
+
+import { StageHost } from "#flow/stages/base";
+
+import {
+    instanceOfValidationError,
+    Prompt,
+    PromptChallenge,
+    PromptTypeEnum,
+    StagesApi,
+} from "@goauthentik/api";
 
 import { msg } from "@lit/localize";
-import { CSSResult, TemplateResult, html } from "lit";
+import { CSSResult, html, TemplateResult } from "lit";
 import { customElement, state } from "lit/decorators.js";
 import { ifDefined } from "lit/directives/if-defined.js";
 import { map } from "lit/directives/map.js";
@@ -16,14 +27,6 @@ import { map } from "lit/directives/map.js";
 import PFTitle from "@patternfly/patternfly/components/Title/title.css";
 import PFGrid from "@patternfly/patternfly/layouts/Grid/grid.css";
 
-import {
-    Prompt,
-    PromptChallenge,
-    PromptTypeEnum,
-    StagesApi,
-    instanceOfValidationError,
-} from "@goauthentik/api";
-
 class PreviewStageHost implements StageHost {
     challenge = undefined;
     flowSlug = undefined;
@@ -70,7 +73,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
 
     async refreshPreview(prompt?: Prompt): Promise<void> {
         if (!prompt) {
-            prompt = this.serializeForm();
+            prompt = this.serialize();
             if (!prompt) {
                 return;
             }
@@ -99,9 +102,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
             : msg("Successfully created prompt.");
     }
 
-    static get styles(): CSSResult[] {
-        return super.styles.concat(PFGrid, PFTitle);
-    }
+    static styles: CSSResult[] = [...super.styles, PFGrid, PFTitle];
 
     _shouldRefresh = false;
     _timer = 0;
@@ -203,7 +204,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
     }
 
     renderEditForm(): TemplateResult {
-        return html` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
+        return html` <ak-form-element-horizontal label=${msg("Name")} required name="name">
                 <input
                     type="text"
                     value="${ifDefined(this.instance?.name)}"
@@ -217,7 +218,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
                     ${msg("Unique name of this field, used for selecting fields in prompt stages.")}
                 </p>
             </ak-form-element-horizontal>
-            <ak-form-element-horizontal label=${msg("Field Key")} ?required=${true} name="fieldKey">
+            <ak-form-element-horizontal label=${msg("Field Key")} required name="fieldKey">
                 <input
                     type="text"
                     value="${ifDefined(this.instance?.fieldKey)}"
@@ -238,7 +239,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
                     )}
                 </p>
             </ak-form-element-horizontal>
-            <ak-form-element-horizontal label=${msg("Label")} ?required=${true} name="label">
+            <ak-form-element-horizontal label=${msg("Label")} required name="label">
                 <input
                     type="text"
                     value="${ifDefined(this.instance?.label)}"
@@ -252,7 +253,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
                     ${msg("Label shown next to/above the prompt.")}
                 </p>
             </ak-form-element-horizontal>
-            <ak-form-element-horizontal label=${msg("Type")} ?required=${true} name="type">
+            <ak-form-element-horizontal label=${msg("Type")} required name="type">
                 <select
                     class="pf-c-form-control"
                     @change=${() => {
@@ -371,7 +372,7 @@ export class PromptForm extends ModelForm<Prompt, string> {
                 </ak-codemirror>
                 <p class="pf-c-form__helper-text">${msg("Any HTML can be used.")}</p>
             </ak-form-element-horizontal>
-            <ak-form-element-horizontal label=${msg("Order")} ?required=${true} name="order">
+            <ak-form-element-horizontal label=${msg("Order")} required name="order">
                 <input
                     type="number"
                     value="${this.instance?.order ?? 0}"
