@@ -1,11 +1,7 @@
-import {
-    CSRFMiddleware,
-    EventMiddleware,
-    LoggingMiddleware,
-} from "@goauthentik/common/api/middleware.js";
-import { EVENT_LOCALE_REQUEST } from "@goauthentik/common/constants.js";
-import { globalAK } from "@goauthentik/common/global.js";
-import { SentryMiddleware } from "@goauthentik/common/sentry/middleware";
+import { CSRFMiddleware, EventMiddleware, LoggingMiddleware } from "#common/api/middleware";
+import { EVENT_LOCALE_REQUEST } from "#common/constants";
+import { globalAK } from "#common/global";
+import { SentryMiddleware } from "#common/sentry/middleware";
 
 import { Config, Configuration, CoreApi, CurrentBrand, RootApi } from "@goauthentik/api";
 
