@@ -1,9 +1,9 @@
+import { HorizontalLightComponent } from "./HorizontalLightComponent.js";
+
 import { html } from "lit";
 import { customElement, property } from "lit/decorators.js";
 import { ifDefined } from "lit/directives/if-defined.js";
 
-import { HorizontalLightComponent } from "./HorizontalLightComponent";
-
 @customElement("ak-number-input")
 export class AkNumberInput extends HorizontalLightComponent<number> {
     @property({ type: Number, reflect: true })
@@ -21,6 +21,7 @@ export class AkNumberInput extends HorizontalLightComponent<number> {
         return html`<input
             type="number"
             @input=${setValue}
+            aria-label=${ifDefined(this.label)}
             value=${ifDefined(this.value)}
             min=${ifDefined(this.min)}
             class="pf-c-form-control"
