@@ -1,10 +1,13 @@
-import { RadioOption } from "@goauthentik/elements/forms/Radio";
-import "@goauthentik/elements/forms/Radio";
+import "#elements/forms/Radio";
+
+import { HorizontalLightComponent } from "./HorizontalLightComponent.js";
+
+import { RadioOption } from "#elements/forms/Radio";
+import { SlottedTemplateResult } from "#elements/types";
 
 import { html, nothing } from "lit";
 import { customElement, property } from "lit/decorators.js";
-
-import { HorizontalLightComponent } from "./HorizontalLightComponent";
+import { ifDefined } from "lit/directives/if-defined.js";
 
 @customElement("ak-radio-input")
 export class AkRadioInput<T> extends HorizontalLightComponent<T> {
@@ -20,20 +23,20 @@ export class AkRadioInput<T> extends HorizontalLightComponent<T> {
         }
     }
 
-    renderHelp() {
-        // This is weird, but Typescript says it's necessary?
-        return [nothing as typeof nothing];
+    protected override renderHelp(): SlottedTemplateResult {
+        return nothing;
     }
 
     renderControl() {
+        const helpText = this.help.trim();
+
         return html`<ak-radio
+                label=${ifDefined(this.label)}
                 .options=${this.options}
                 .value=${this.value}
                 @input=${this.handleInput}
             ></ak-radio>
-            ${this.help.trim()
-                ? html`<p class="pf-c-form__helper-radio">${this.help}</p>`
-                : nothing}`;
+            ${helpText ? html`<p class="pf-c-form__helper-radio">${helpText}</p>` : nothing}`;
     }
 }
 
