@@ -1,6 +1,6 @@
-import { createContext } from "@lit/context";
+import type { WizardStepState } from "./types.js";
 
-import type { WizardStepState } from "./types";
+import { createContext } from "@lit/context";
 
 export const wizardStepContext = createContext<WizardStepState>(
     Symbol.for("authentik-wizard-step-labels"),
