@@ -1,10 +1,11 @@
-import "@goauthentik/elements/messages/MessageContainer";
+import "#elements/messages/MessageContainer";
+import "../ak-textarea-input.js";
+
+import AkTextareaInput from "../ak-textarea-input.js";
+
 import { Meta } from "@storybook/web-components";
 
-import { TemplateResult, html } from "lit";
-
-import "../ak-textarea-input";
-import AkTextareaInput from "../ak-textarea-input";
+import { html, TemplateResult } from "lit";
 
 const metadata: Meta<AkTextareaInput> = {
     title: "Components / Textarea Input",
@@ -21,7 +22,7 @@ const metadata: Meta<AkTextareaInput> = {
 export default metadata;
 
 const container = (testItem: TemplateResult) =>
-    html` <div style="background: #000; padding: 2em">
+    html` <div style="padding: 2em">
         <style>
             li {
                 display: block;
