@@ -1,5 +1,6 @@
-import { AKElement } from "@goauthentik/elements/Base";
-import { type SlottedTemplateResult, type Spread } from "@goauthentik/elements/types";
+import { AKElement } from "#elements/Base";
+import { type SlottedTemplateResult, type Spread } from "#elements/types";
+
 import { spread } from "@open-wc/lit-helpers";
 
 import { css, html, nothing } from "lit";
@@ -35,17 +36,17 @@ export interface IAlert {
  * make, as well as in in-line documentation.
  */
 @customElement("ak-alert")
-export class Alert extends AKElement implements IAlert {
+export class AKAlert extends AKElement implements IAlert {
     /**
      * Whether or not to display the entire component's contents in-line or not.
      *
      * @attr
      */
     @property({ type: Boolean })
-    inline = false;
+    public inline?: boolean;
 
     @property({ type: Boolean })
-    plain = false;
+    public plain?: boolean;
 
     /**
      * Method of determining severity
@@ -61,28 +62,27 @@ export class Alert extends AKElement implements IAlert {
      * @attr
      */
     @property()
-    icon = "fa-exclamation-circle";
+    public icon = "fa-exclamation-circle";
 
-    static get styles() {
-        return [
-            PFBase,
-            PFAlert,
-            css`
-                p {
-                    margin: 0;
-                }
-            `,
-        ];
-    }
+    static styles = [
+        PFBase,
+        PFAlert,
+        css`
+            p {
+                margin: 0;
+            }
+        `,
+    ];
 
     get classmap() {
         const level = levelNames.includes(this.level)
             ? `pf-m-${this.level}`
             : (this.level as string);
+
         return {
             "pf-c-alert": true,
-            "pf-m-inline": this.inline,
-            "pf-m-plain": this.plain,
+            "pf-m-inline": !!this.inline,
+            "pf-m-plain": !!this.plain,
             [level]: true,
         };
     }
@@ -90,9 +90,9 @@ export class Alert extends AKElement implements IAlert {
     render() {
         return html`<div class="${classMap(this.classmap)}">
             <div class="pf-c-alert__icon">
-                <i class="fas ${this.icon}"></i>
+                <i aria-hidden="true" class="fas ${this.icon}"></i>
             </div>
-            <h4 class="pf-c-alert__title"><slot></slot></h4>
+            <h4 role="presentation" class="pf-c-alert__title"><slot></slot></h4>
         </div>`;
     }
 }
@@ -104,6 +104,6 @@ export function akAlert(properties: IAlert, content: SlottedTemplateResult = not
 
 declare global {
     interface HTMLElementTagNameMap {
-        "ak-alert": Alert;
+        "ak-alert": AKAlert;
     }
 }
