@@ -1,5 +1,6 @@
-import { AKElement } from "@goauthentik/elements/Base";
-import type { SlottedTemplateResult, Spread } from "@goauthentik/elements/types";
+import { AKElement } from "#elements/Base";
+import type { SlottedTemplateResult, Spread } from "#elements/types";
+
 import { spread } from "@open-wc/lit-helpers";
 
 import { css, html, nothing } from "lit";
@@ -13,6 +14,7 @@ export enum PFColor {
     Green = "pf-m-green",
     Orange = "pf-m-orange",
     Red = "pf-m-red",
+    Blue = "pf-m-blue",
     Grey = "",
 }
 
@@ -24,6 +26,7 @@ const chromeList: Chrome[] = [
     ["danger", PFColor.Red, "pf-m-red", "fa-times"],
     ["warning", PFColor.Orange, "pf-m-orange", "fa-exclamation-triangle"],
     ["success", PFColor.Green, "pf-m-green", "fa-check"],
+    ["running", PFColor.Blue, "pf-m-blue", "fa-clock"],
     ["info", PFColor.Grey, "pf-m-grey", "fa-info-circle"],
 ];
 
