@@ -1,10 +1,11 @@
-import { PropertyValues, html } from "lit";
-import { customElement, property } from "lit/decorators.js";
-import { ref } from "lit/directives/ref.js";
+import "./ak-dual-select.js";
 
 import { AkDualSelectProvider } from "./ak-dual-select-provider.js";
-import "./ak-dual-select.js";
-import type { DualSelectPair, DualSelectPairSource } from "./types.js";
+import type { DualSelectPairSource } from "./types.js";
+
+import { html, PropertyValues } from "lit";
+import { customElement, property } from "lit/decorators.js";
+import { ref } from "lit/directives/ref.js";
 
 /**
  * @element ak-dual-select-dynamic-provider
