@@ -1,16 +1,17 @@
-import { AkControlElement } from "@goauthentik/elements/AkControlElement.js";
-import { CustomListenerElement } from "@goauthentik/elements/utils/eventEmitter.js";
+import "./ak-dual-select.js";
 
-import { msg } from "@lit/localize";
-import { PropertyValues, html } from "lit";
-import { customElement, property, state } from "lit/decorators.js";
-import { createRef, ref } from "lit/directives/ref.js";
+import { AkDualSelect } from "./ak-dual-select.js";
+import { type DataProvider, DualSelectEventType, type DualSelectPair } from "./types.js";
+
+import { AkControlElement } from "#elements/AkControlElement";
+import { CustomListenerElement } from "#elements/utils/eventEmitter";
 
 import type { Pagination } from "@goauthentik/api";
 
-import "./ak-dual-select.js";
-import { AkDualSelect } from "./ak-dual-select.js";
-import { type DataProvider, DualSelectEventType, type DualSelectPair } from "./types.js";
+import { msg } from "@lit/localize";
+import { html, PropertyValues } from "lit";
+import { customElement, property, state } from "lit/decorators.js";
+import { createRef, ref } from "lit/directives/ref.js";
 
 /**
  * @element ak-dual-select-provider
