@@ -1,5 +1,8 @@
-import { AKElement } from "@goauthentik/elements/Base";
-import { CustomEmitterElement } from "@goauthentik/elements/utils/eventEmitter";
+import type { SearchbarEventDetail, SearchbarEventSource } from "../types.ts";
+import { globalVariables, searchStyles } from "./search.styles.js";
+
+import { AKElement } from "#elements/Base";
+import { CustomEmitterElement } from "#elements/utils/eventEmitter";
 
 import { html } from "lit";
 import { customElement, property } from "lit/decorators.js";
@@ -7,9 +10,6 @@ import { createRef, ref } from "lit/directives/ref.js";
 
 import PFBase from "@patternfly/patternfly/patternfly-base.css";
 
-import type { SearchbarEventDetail, SearchbarEventSource } from "../types.ts";
-import { globalVariables, searchStyles } from "./search.css.js";
-
 @customElement("ak-search-bar")
 export class AkSearchbar extends CustomEmitterElement(AKElement) {
     static styles = [PFBase, globalVariables, searchStyles];
