@@ -1,6 +1,7 @@
-import "./ak-dual-select-provider";
-import { AkDualSelectProvider } from "./ak-dual-select-provider.js";
+import "./ak-dual-select-provider.js";
 import "./ak-dual-select.js";
+
+import { AkDualSelectProvider } from "./ak-dual-select-provider.js";
 import { AkDualSelect } from "./ak-dual-select.js";
 
 export { AkDualSelect, AkDualSelectProvider };
