@@ -1,12 +1,13 @@
-import { EVENT_LOCALE_REQUEST } from "@goauthentik/common/constants";
-import { customEvent } from "@goauthentik/elements/utils/customEvents";
+import "./ak-locale-context.js";
+
+import { EVENT_LOCALE_REQUEST } from "#common/constants";
+
+import { customEvent } from "#elements/utils/customEvents";
 
 import { localized, msg } from "@lit/localize";
-import { LitElement, html } from "lit";
+import { html, LitElement } from "lit";
 import { customElement } from "lit/decorators.js";
 
-import "./ak-locale-context";
-
 export default {
     title: "Elements / Shell / Locale Context",
 };
@@ -28,7 +29,7 @@ export class AKLocaleSensitiveDemoComponent extends LitElement {
 }
 
 export const InFrench = () =>
-    html`<div style="background: #fff; padding: 4em">
+    html`<div style="padding: 4em">
         <ak-locale-context locale="fr"
             ><ak-locale-demo-component
                 >Everything is not ok.</ak-locale-demo-component
@@ -43,7 +44,7 @@ export const SwitchingBackAndForth = () => {
         window.dispatchEvent(customEvent(EVENT_LOCALE_REQUEST, { locale: lang }));
     }, 1000);
 
-    return html`<div style="background: #fff; padding: 4em">
+    return html`<div style="padding: 4em">
         <ak-locale-context locale="fr">
             <ak-locale-sensitive-demo-component></ak-locale-sensitive-demo-component
         ></ak-locale-context>
