@@ -1,4 +1,4 @@
-import LocaleContext from "./ak-locale-context";
+import LocaleContext from "./ak-locale-context.js";
 
 export { LocaleContext };
 export default LocaleContext;
