@@ -1,13 +1,15 @@
-import { render } from "@goauthentik/elements/tests/utils.js";
+import "../ak-select-table.js";
+
+import { nutritionDbUSDA as unsortedNutritionDbUSDA } from "../stories/sample_nutrition_db.js";
+
+import { render } from "#elements/tests/utils";
+
 import { $, browser } from "@wdio/globals";
 import { expect } from "expect-webdriverio";
 import { slug } from "github-slugger";
 
 import { html } from "lit";
 
-import "../ak-select-table.js";
-import { nutritionDbUSDA as unsortedNutritionDbUSDA } from "../stories/sample_nutrition_db.js";
-
 type SortableRecord = Record<string, string | number>;
 
 const dbSort = (a: SortableRecord, b: SortableRecord) =>
