@@ -1,13 +1,15 @@
-import { render } from "@goauthentik/elements/tests/utils.js";
+import "#elements/ak-table/ak-simple-table";
+
+import { nutritionDbUSDA } from "../stories/sample_nutrition_db.js";
+
+import { render } from "#elements/tests/utils";
+
 import { $, browser } from "@wdio/globals";
 import { expect } from "expect-webdriverio";
 import { slug } from "github-slugger";
 
 import { html } from "lit";
 
-import "../ak-simple-table.js";
-import { nutritionDbUSDA } from "../stories/sample_nutrition_db.js";
-
 const columns = ["Name", "Calories", "Protein", "Fiber", "Sugar"];
 const content = nutritionDbUSDA.map(({ name, calories, sugar, fiber, protein }) => ({
     key: slug(name),
