@@ -1,4 +1,4 @@
-import { ActionButton } from "./ak-action-button";
+import { ActionButton } from "./ak-action-button.js";
 
 export { ActionButton };
 export default ActionButton;
