@@ -1,7 +1,8 @@
-import { EVENT_REFRESH } from "@goauthentik/common/constants";
-import { AKElement } from "@goauthentik/elements/Base";
+import { EVENT_REFRESH } from "#common/constants";
 
-import { TemplateResult, html } from "lit";
+import { AKElement } from "#elements/Base";
+
+import { html, TemplateResult } from "lit";
 import { customElement } from "lit/decorators.js";
 
 @customElement("ak-dropdown")
