@@ -1,4 +1,4 @@
-import SpinnerButton from "./ak-spinner-button";
+import SpinnerButton from "./ak-spinner-button.js";
 
 export { SpinnerButton };
 export default SpinnerButton;
