@@ -1,4 +1,4 @@
-import { TokenCopyButton } from "./ak-token-copy-button";
+import { TokenCopyButton } from "./ak-token-copy-button.js";
 
 export { TokenCopyButton };
 export default TokenCopyButton;
