@@ -1,42 +1,67 @@
-import { EVENT_REFRESH } from "@goauthentik/common/constants";
-import "@goauthentik/elements/LoadingOverlay";
-import { ModalButton } from "@goauthentik/elements/buttons/ModalButton";
-import "@goauthentik/elements/buttons/SpinnerButton";
-import { ModalHideEvent } from "@goauthentik/elements/controllers/ModalOrchestrationController.js";
-import { Form } from "@goauthentik/elements/forms/Form";
+import "#elements/LoadingOverlay";
+import "#elements/buttons/SpinnerButton/index";
+
+import { EVENT_REFRESH } from "#common/constants";
+
+import { ModalButton } from "#elements/buttons/ModalButton";
+import { ModalHideEvent } from "#elements/controllers/ModalOrchestrationController";
+import { Form } from "#elements/forms/Form";
 
 import { msg } from "@lit/localize";
-import { TemplateResult, html } from "lit";
+import { html, nothing, TemplateResult } from "lit";
 import { customElement, property } from "lit/decorators.js";
 
 @customElement("ak-forms-modal")
 export class ModalForm extends ModalButton {
-    @property({ type: Boolean })
-    closeAfterSuccessfulSubmit = true;
+    //#region Properties
 
     @property({ type: Boolean })
-    showSubmitButton = true;
+    public closeAfterSuccessfulSubmit = true;
 
     @property({ type: Boolean })
-    loading = false;
+    public showSubmitButton = true;
+
+    @property({ type: Boolean })
+    public loading = false;
 
     @property({ type: String })
-    cancelText = msg("Cancel");
+    public cancelText = msg("Cancel");
+
+    //#endregion
+
+    #confirm = async (): Promise<void> => {
+        const form = this.querySelector<Form>("[slot=form]");
 
-    async confirm(): Promise<void> {
-        const form = this.querySelector<Form<unknown>>("[slot=form]");
         if (!form) {
-            return Promise.reject(msg("No form found"));
+            throw new Error(msg("No form found"));
         }
-        const formPromise = form.submit(new Event("submit"));
-        if (!formPromise) {
-            return Promise.reject(msg("Form didn't return a promise for submitting"));
+
+        if (!(form instanceof Form)) {
+            console.warn("authentik/forms: form inside the form slot is not a Form", form);
+            throw new Error(msg("Element inside the form slot is not a Form"));
         }
+
+        if (!form.reportValidity()) {
+            this.loading = false;
+            this.locked = false;
+
+            return;
+        }
+
+        this.loading = true;
+        this.locked = true;
+
+        const formPromise = form.submit(
+            new SubmitEvent("submit", {
+                submitter: this,
+            }),
+        );
+
         return formPromise
             .then(() => {
                 if (this.closeAfterSuccessfulSubmit) {
                     this.open = false;
-                    form?.resetForm();
+                    form?.reset();
 
                     // TODO: We may be fetching too frequently.
                     // Repeat dispatching will prematurely abort refresh listeners and cause several fetches and re-renders.
@@ -47,6 +72,7 @@ export class ModalForm extends ModalButton {
                         }),
                     );
                 }
+
                 this.loading = false;
                 this.locked = false;
             })
@@ -56,12 +82,28 @@ export class ModalForm extends ModalButton {
 
                 throw error;
             });
-    }
+    };
 
-    renderModalInner(): TemplateResult {
+    #cancel = (): void => {
+        const defaultInvoked = this.dispatchEvent(new ModalHideEvent(this));
+
+        if (defaultInvoked) {
+            this.resetForms();
+        }
+    };
+
+    #scrollListener = () => {
+        window.dispatchEvent(
+            new CustomEvent("scroll", {
+                bubbles: true,
+            }),
+        );
+    };
+
+    protected renderModalInner(): TemplateResult {
         return html`${this.loading
                 ? html`<ak-loading-overlay topmost></ak-loading-overlay>`
-                : html``}
+                : nothing}
             <section class="pf-c-modal-box__header pf-c-page__main-section pf-m-light">
                 <div class="pf-c-content">
                     <h1 class="pf-c-title pf-m-2xl">
@@ -70,37 +112,16 @@ export class ModalForm extends ModalButton {
                 </div>
             </section>
             <slot name="above-form"></slot>
-            <section
-                class="pf-c-modal-box__body"
-                @scroll=${() => {
-                    window.dispatchEvent(
-                        new CustomEvent("scroll", {
-                            bubbles: true,
-                        }),
-                    );
-                }}
-            >
+            <section class="pf-c-modal-box__body" @scroll=${this.#scrollListener}>
                 <slot name="form"></slot>
             </section>
             <footer class="pf-c-modal-box__footer">
                 ${this.showSubmitButton
-                    ? html`<ak-spinner-button
-                              .callAction=${() => {
-                                  this.loading = true;
-                                  this.locked = true;
-                                  return this.confirm();
-                              }}
-                              class="pf-m-primary"
-                          >
+                    ? html`<ak-spinner-button .callAction=${this.#confirm} class="pf-m-primary">
                               <slot name="submit"></slot> </ak-spinner-button
                           >&nbsp;`
-                    : html``}
-                <ak-spinner-button
-                    .callAction=${async () => {
-                        this.dispatchEvent(new ModalHideEvent(this));
-                    }}
-                    class="pf-m-secondary"
-                >
+                    : nothing}
+                <ak-spinner-button .callAction=${this.#cancel} class="pf-m-secondary">
                     ${this.cancelText}
                 </ak-spinner-button>
             </footer>`;
