@@ -1,51 +1,68 @@
-import { EVENT_REFRESH } from "@goauthentik/common/constants";
-import "@goauthentik/elements/EmptyState";
-import { Form } from "@goauthentik/elements/forms/Form";
+import "#elements/EmptyState";
 
-import { TemplateResult, html } from "lit";
+import { EVENT_REFRESH } from "#common/constants";
+
+import { Form } from "#elements/forms/Form";
+import { SlottedTemplateResult } from "#elements/types";
+
+import { html, TemplateResult } from "lit";
 import { property } from "lit/decorators.js";
 
 /**
- * Model form
- *
  * A base form that automatically tracks the server-side object (instance)
  * that we're interested in.  Handles loading and tracking of the instance.
  */
-
 export abstract class ModelForm<T, PKT extends string | number> extends Form<T> {
-    abstract loadInstance(pk: PKT): Promise<T>;
+    /**
+     * An overridable method for loading an instance.
+     *
+     * @param pk The primary key of the instance to load.
+     * @returns A promise that resolves to the loaded instance.
+     */
+    protected abstract loadInstance(pk: PKT): Promise<T>;
 
+    /**
+     * An overridable method for loading any data, beyond the instance.
+     *
+     * @see {@linkcode loadInstance}
+     * @returns A promise that resolves when the data has been loaded.
+     */
     async load(): Promise<void> {
         return Promise.resolve();
     }
 
     @property({ attribute: false })
-    set instancePk(value: PKT) {
-        this._instancePk = value;
+    public set instancePk(value: PKT) {
+        this.#instancePk = value;
+
         if (this.viewportCheck && !this.isInViewport) {
             return;
         }
-        if (this._isLoading) {
+
+        if (this.#loading) {
             return;
         }
-        this._isLoading = true;
+
+        this.#loading = true;
+
         this.load().then(() => {
             this.loadInstance(value).then((instance) => {
                 this.instance = instance;
-                this._isLoading = false;
+                this.#loading = false;
                 this.requestUpdate();
             });
         });
     }
 
-    private _instancePk?: PKT;
+    #instancePk?: PKT;
 
     // Keep track if we've loaded the model instance
-    private _initialLoad = false;
-    // Keep track if we've done the general data loading of load()
-    private _initialDataLoad = false;
+    #initialLoad = false;
 
-    private _isLoading = false;
+    // Keep track if we've done the general data loading of load()
+    #initialDataLoad = false;
+
+    #loading = false;
 
     @property({ attribute: false })
     instance?: T = this.defaultInstance;
@@ -56,43 +73,45 @@ export abstract class ModelForm<T, PKT extends string | number> extends Form<T>
 
     constructor() {
         super();
+
         this.addEventListener(EVENT_REFRESH, () => {
-            if (!this._instancePk) return;
-            this.loadInstance(this._instancePk).then((instance) => {
+            if (!this.#instancePk) return;
+            this.loadInstance(this.#instancePk).then((instance) => {
                 this.instance = instance;
             });
         });
     }
 
-    resetForm(): void {
+    reset(): void {
         this.instance = undefined;
-        this._initialLoad = false;
+        this.#initialLoad = false;
     }
 
     renderVisible(): TemplateResult {
-        if ((this._instancePk && !this.instance) || !this._initialDataLoad) {
+        if ((this.#instancePk && !this.instance) || !this.#initialDataLoad) {
             return html`<ak-empty-state loading></ak-empty-state>`;
         }
         return super.renderVisible();
     }
 
-    render(): TemplateResult {
+    render(): SlottedTemplateResult {
         // if we're in viewport now and haven't loaded AND have a PK set, load now
         // Or if we don't check for viewport in some cases
         const viewportVisible = this.isInViewport || !this.viewportCheck;
-        if (this._instancePk && !this._initialLoad && viewportVisible) {
-            this.instancePk = this._instancePk;
-            this._initialLoad = true;
-        } else if (!this._initialDataLoad && viewportVisible) {
+        if (this.#instancePk && !this.#initialLoad && viewportVisible) {
+            this.instancePk = this.#instancePk;
+            this.#initialLoad = true;
+        } else if (!this.#initialDataLoad && viewportVisible) {
             // else if since if the above case triggered that will also call this.load(), so
             // ensure we don't load again
             this.load().then(() => {
-                this._initialDataLoad = true;
+                this.#initialDataLoad = true;
                 // Class attributes changed in this.load() might not be @property()
                 // or @state() so let's trigger a re-render to be sure we get updated
                 this.requestUpdate();
             });
         }
+
         return super.render();
     }
 }
