@@ -1,4 +1,4 @@
-import { SearchSelect } from "./ak-search-select";
+import { SearchSelect } from "./ak-search-select.js";
 
 export { SearchSelect };
 export default SearchSelect;
