@@ -1,4 +1,4 @@
-import { HorizontalFormElement } from "@goauthentik/elements/forms/HorizontalFormElement";
+import { HorizontalFormElement } from "#elements/forms/HorizontalFormElement";
 
 export class PreventFormSubmit {
     // Stub class which can be returned by form elements to prevent the form from submitting
