@@ -1,9 +1,9 @@
 import { createMixin } from "#elements/types";
 
-import { Context, consume, createContext } from "@lit/context";
-
 import type { Version } from "@goauthentik/api";
 
+import { consume, Context, createContext } from "@lit/context";
+
 /**
  * The Lit context for application branding.
  *
