@@ -1,6 +1,6 @@
-import "@goauthentik/elements/EmptyState";
+import "#elements/EmptyState";
 
-import { TemplateResult, html } from "lit";
+import { html, TemplateResult } from "lit";
 import { until } from "lit/directives/until.js";
 
 export const SLUG_REGEX = "[-a-zA-Z0-9_]+";
