@@ -1,23 +1,27 @@
-import { EVENT_REFRESH } from "@goauthentik/common/constants";
-import {
-    APIError,
-    parseAPIResponseError,
-    pluckErrorDetail,
-} from "@goauthentik/common/errors/network";
-import { uiConfig } from "@goauthentik/common/ui/config";
-import { groupBy } from "@goauthentik/common/utils";
-import { AKElement } from "@goauthentik/elements/Base";
-import "@goauthentik/elements/EmptyState";
-import "@goauthentik/elements/buttons/SpinnerButton";
-import "@goauthentik/elements/chips/Chip";
-import "@goauthentik/elements/chips/ChipGroup";
-import { getURLParam, updateURLParams } from "@goauthentik/elements/router/RouteMatch";
-import "@goauthentik/elements/table/TablePagination";
-import "@goauthentik/elements/table/TableSearch";
-import { SlottedTemplateResult } from "@goauthentik/elements/types";
+import "#elements/EmptyState";
+import "#elements/buttons/SpinnerButton/index";
+import "#elements/chips/Chip";
+import "#elements/chips/ChipGroup";
+import "#elements/table/TablePagination";
+import "#elements/table/TableSearch";
 
-import { msg } from "@lit/localize";
-import { CSSResult, PropertyValues, TemplateResult, css, html, nothing } from "lit";
+import { TableLike } from "./shared.js";
+import { TableColumn } from "./TableColumn.js";
+
+import { EVENT_REFRESH } from "#common/constants";
+import { APIError, parseAPIResponseError, pluckErrorDetail } from "#common/errors/network";
+import { uiConfig } from "#common/ui/config";
+import { groupBy } from "#common/utils";
+
+import { AKElement } from "#elements/Base";
+import { WithLicenseSummary } from "#elements/mixins/license";
+import { getURLParam, updateURLParams } from "#elements/router/RouteMatch";
+import { SlottedTemplateResult } from "#elements/types";
+
+import { Pagination } from "@goauthentik/api";
+
+import { msg, str } from "@lit/localize";
+import { css, CSSResult, html, nothing, PropertyValues, TemplateResult } from "lit";
 import { property, state } from "lit/decorators.js";
 import { classMap } from "lit/directives/class-map.js";
 import { ifDefined } from "lit/directives/if-defined.js";
@@ -31,102 +35,82 @@ import PFToolbar from "@patternfly/patternfly/components/Toolbar/toolbar.css";
 import PFBullseye from "@patternfly/patternfly/layouts/Bullseye/bullseye.css";
 import PFBase from "@patternfly/patternfly/patternfly-base.css";
 
-import { Pagination } from "@goauthentik/api";
-
-export interface TableLike {
-    order?: string;
-    fetch: () => void;
-}
-
-export class TableColumn {
-    title: string;
-    orderBy?: string;
-
-    onClick?: () => void;
-
-    constructor(title: string, orderBy?: string) {
-        this.title = title;
-        this.orderBy = orderBy;
-    }
-
-    headerClickHandler(table: TableLike): void {
-        if (!this.orderBy) {
-            return;
-        }
-        table.order = table.order === this.orderBy ? `-${this.orderBy}` : this.orderBy;
-        table.fetch();
-    }
-
-    private getSortIndicator(table: TableLike): string {
-        switch (table.order) {
-            case this.orderBy:
-                return "fa-long-arrow-alt-down";
-            case `-${this.orderBy}`:
-                return "fa-long-arrow-alt-up";
-            default:
-                return "fa-arrows-alt-v";
-        }
-    }
-
-    renderSortable(table: TableLike): TemplateResult {
-        return html` <button
-            class="pf-c-table__button"
-            @click=${() => this.headerClickHandler(table)}
-        >
-            <div class="pf-c-table__button-content">
-                <span class="pf-c-table__text">${this.title}</span>
-                <span class="pf-c-table__sort-indicator">
-                    <i class="fas ${this.getSortIndicator(table)}"></i>
-                </span>
-            </div>
-        </button>`;
-    }
-
-    render(table: TableLike): TemplateResult {
-        const classes = {
-            "pf-c-table__sort": !!this.orderBy,
-            "pf-m-selected": table.order === this.orderBy || table.order === `-${this.orderBy}`,
-        };
-
-        return html`<th role="columnheader" scope="col" class="${classMap(classes)}">
-            ${this.orderBy ? this.renderSortable(table) : html`${this.title}`}
-        </th>`;
-    }
-}
+export * from "./shared.js";
+export * from "./TableColumn.js";
 
 export interface PaginatedResponse<T> {
     pagination: Pagination;
+    autocomplete?: { [key: string]: string };
 
     results: Array<T>;
 }
 
-export abstract class Table<T> extends AKElement implements TableLike {
+export abstract class Table<T extends object>
+    extends WithLicenseSummary(AKElement)
+    implements TableLike
+{
+    static styles: CSSResult[] = [
+        PFBase,
+        PFTable,
+        PFBullseye,
+        PFButton,
+        PFSwitch,
+        PFToolbar,
+        PFDropdown,
+        PFPagination,
+        css`
+            .pf-c-toolbar__group.pf-m-search-filter.ql {
+                flex-grow: 1;
+            }
+            ak-table-search.ql {
+                width: 100% !important;
+            }
+            .pf-c-table thead .pf-c-table__check {
+                min-width: 3rem;
+            }
+            .pf-c-table tbody .pf-c-table__check input {
+                margin-top: calc(var(--pf-c-table__check--input--MarginTop) + 1px);
+            }
+            .pf-c-toolbar__content {
+                row-gap: var(--pf-global--spacer--sm);
+            }
+            .pf-c-toolbar__item .pf-c-input-group {
+                padding: 0 var(--pf-global--spacer--sm);
+            }
+
+            .pf-c-table {
+                --pf-c-table--m-striped__tr--BackgroundColor: var(
+                    --pf-global--BackgroundColor--dark-300
+                );
+            }
+        `,
+    ];
+
     abstract apiEndpoint(): Promise<PaginatedResponse<T>>;
     abstract columns(): TableColumn[];
     abstract row(item: T): SlottedTemplateResult[];
 
-    private isLoading = false;
+    #loading = false;
 
     #pageParam = `${this.tagName.toLowerCase()}-page`;
     #searchParam = `${this.tagName.toLowerCase()}-search`;
 
-    searchEnabled(): boolean {
-        return false;
-    }
+    @property({ type: Boolean })
+    public supportsQL: boolean = false;
 
-    renderExpanded(_item: T): SlottedTemplateResult {
-        if (this.expandable) {
-            throw new Error("Expandable is enabled but renderExpanded is not overridden!");
-        }
+    //#region Properties
 
-        return nothing;
-    }
+    @property({ type: String })
+    public toolbarLabel = msg("Table actions");
+
+    @property({ type: String })
+    public label?: string;
 
     @property({ attribute: false })
-    data?: PaginatedResponse<T>;
+    public data?: PaginatedResponse<T>;
 
     @property({ type: Number })
-    page = getURLParam(this.#pageParam, 1);
+    public page = getURLParam(this.#pageParam, 1);
 
     /**
      * Set if your `selectedElements` use of the selection box is to enable bulk-delete,
@@ -135,87 +119,91 @@ export abstract class Table<T> extends AKElement implements TableLike {
      * @prop
      */
     @property({ attribute: "clear-on-refresh", type: Boolean, reflect: true })
-    clearOnRefresh = false;
+    public clearOnRefresh = false;
 
     @property({ type: String })
-    order?: string;
+    public order?: string;
 
-    @property({ type: String })
-    search: string = "";
+    @property({ type: String, attribute: false })
+    public search?: string;
 
     @property({ type: Boolean })
-    checkbox = false;
+    public checkbox = false;
 
     @property({ type: Boolean })
-    clickable = false;
+    public clickable = false;
 
     @property({ attribute: false })
-    clickHandler: (item: T) => void = () => {};
+    public clickHandler: (item: T) => void = () => {};
 
     @property({ type: Boolean })
-    radioSelect = false;
+    public radioSelect = false;
 
     @property({ type: Boolean })
-    checkboxChip = false;
+    public checkboxChip = false;
 
     @property({ attribute: false })
-    selectedElements: T[] = [];
+    public selectedElements: T[] = [];
 
     @property({ type: Boolean })
-    paginated = true;
+    public paginated = true;
 
     @property({ type: Boolean })
-    expandable = false;
+    public expandable = false;
 
     @property({ attribute: false })
-    expandedElements: T[] = [];
+    public expandedElements: T[] = [];
+
+    @property({ attribute: false })
+    public searchLabel?: string;
+
+    @property({ attribute: false })
+    public searchPlaceholder?: string;
+
+    //#endregion
+
+    //#region Lifecycle
 
     @state()
-    error?: APIError;
+    protected error?: APIError;
 
-    static get styles(): CSSResult[] {
-        return [
-            PFBase,
-            PFTable,
-            PFBullseye,
-            PFButton,
-            PFSwitch,
-            PFToolbar,
-            PFDropdown,
-            PFPagination,
-            css`
-                .pf-c-table thead .pf-c-table__check {
-                    min-width: 3rem;
-                }
-                .pf-c-table tbody .pf-c-table__check input {
-                    margin-top: calc(var(--pf-c-table__check--input--MarginTop) + 1px);
-                }
-                .pf-c-toolbar__content {
-                    row-gap: var(--pf-global--spacer--sm);
-                }
-                .pf-c-toolbar__item .pf-c-input-group {
-                    padding: 0 var(--pf-global--spacer--sm);
-                }
+    #refreshListener = () => {
+        return this.fetch();
+    };
 
-                .pf-c-table {
-                    --pf-c-table--m-striped__tr--BackgroundColor: var(
-                        --pf-global--BackgroundColor--dark-300
-                    );
-                }
-            `,
-        ];
-    }
+    public override connectedCallback(): void {
+        super.connectedCallback();
+        this.addEventListener(EVENT_REFRESH, this.#refreshListener);
 
-    constructor() {
-        super();
-        this.addEventListener(EVENT_REFRESH, async () => {
-            await this.fetch();
-        });
         if (this.searchEnabled()) {
             this.search = getURLParam(this.#searchParam, "");
         }
     }
 
+    public override disconnectedCallback(): void {
+        super.disconnectedCallback();
+        this.removeEventListener(EVENT_REFRESH, this.#refreshListener);
+    }
+
+    protected willUpdate(changedProperties: PropertyValues<this>): void {
+        if (changedProperties.has("page")) {
+            updateURLParams({
+                [this.#pageParam]: this.page,
+            });
+        }
+        if (changedProperties.has("search")) {
+            updateURLParams({
+                [this.#searchParam]: this.search,
+            });
+        }
+    }
+
+    firstUpdated(): void {
+        this.fetch();
+    }
+
+    //#endregion
+
     async defaultEndpointConfig() {
         return {
             ordering: this.order,
@@ -225,16 +213,12 @@ export abstract class Table<T> extends AKElement implements TableLike {
         };
     }
 
-    public groupBy(items: T[]): [SlottedTemplateResult, T[]][] {
-        return groupBy(items, () => {
-            return "";
-        });
-    }
+    public fetch(): Promise<void> {
+        if (this.#loading) {
+            return Promise.resolve();
+        }
 
-    public async fetch(): Promise<void> {
-        if (this.isLoading) return;
-
-        this.isLoading = true;
+        this.#loading = true;
 
         return this.apiEndpoint()
             .then((data) => {
@@ -282,29 +266,32 @@ export abstract class Table<T> extends AKElement implements TableLike {
                 this.error = await parseAPIResponseError(error);
             })
             .finally(() => {
-                this.isLoading = false;
+                this.#loading = false;
                 this.requestUpdate();
             });
     }
 
-    private renderLoading(): TemplateResult {
+    //#region Render
+
+    protected renderLoading(): TemplateResult {
         return html`<tr role="row">
             <td role="cell" colspan="25">
                 <div class="pf-l-bullseye">
-                    <ak-empty-state loading header=${msg("Loading")}></ak-empty-state>
+                    <ak-empty-state default-label></ak-empty-state>
                 </div>
             </td>
         </tr>`;
     }
 
-    renderEmpty(inner?: SlottedTemplateResult): TemplateResult {
+    protected renderEmpty(inner?: SlottedTemplateResult): TemplateResult {
         return html`<tbody role="rowgroup">
             <tr role="row">
                 <td role="cell" colspan="8">
                     <div class="pf-l-bullseye">
                         ${inner ??
-                        html`<ak-empty-state header="${msg("No objects found.")}"
-                            ><div slot="primary">${this.renderObjectCreate()}</div>
+                        html`<ak-empty-state
+                            ><span>${msg("No objects found.")}</span>
+                            <div slot="primary">${this.renderObjectCreate()}</div>
                         </ak-empty-state>`}
                     </div>
                 </td>
@@ -312,23 +299,50 @@ export abstract class Table<T> extends AKElement implements TableLike {
         </tbody>`;
     }
 
-    renderObjectCreate(): SlottedTemplateResult {
+    /**
+     * Render the create object button.
+     *
+     * @abstract
+     */
+    protected renderObjectCreate(): SlottedTemplateResult {
         return nothing;
     }
 
-    renderError(): SlottedTemplateResult {
+    /**
+     * Render the error state.
+     *
+     * @abstract
+     */
+    protected renderError(): SlottedTemplateResult {
         if (!this.error) return nothing;
 
-        return html`<ak-empty-state header="${msg("Failed to fetch objects.")}" icon="fa-ban">
+        return html`<ak-empty-state icon="fa-ban"
+            ><span>${msg("Failed to fetch objects.")}</span>
             <div slot="body">${pluckErrorDetail(this.error)}</div>
         </ak-empty-state>`;
     }
 
+    //#region Rows
+    /**
+     * Render a row for a given item.
+     *
+     * @param item The item to render.
+     */
+    protected rowLabel<T extends object>(item: T): string | typeof nothing {
+        const name = "name" in item && typeof item.name === "string" ? item.name.trim() : null;
+
+        if (!name) {
+            return nothing;
+        }
+
+        return msg(str`${name}`);
+    }
+
     private renderRows(): TemplateResult[] | undefined {
         if (this.error) {
             return [this.renderEmpty(this.renderError())];
         }
-        if (!this.data || this.isLoading) {
+        if (!this.data || this.#loading) {
             return [this.renderLoading()];
         }
         if (this.data.pagination.count === 0) {
@@ -348,7 +362,23 @@ export abstract class Table<T> extends AKElement implements TableLike {
         });
     }
 
+    //#region Grouping
+
+    public groupBy(items: T[]): [SlottedTemplateResult, T[]][] {
+        return groupBy(items, () => "");
+    }
+
+    renderExpanded(_item: T): SlottedTemplateResult {
+        if (this.expandable) {
+            throw new Error("Expandable is enabled but renderExpanded is not overridden!");
+        }
+
+        return nothing;
+    }
+
     private renderRowGroup(items: T[]): TemplateResult[] {
+        const columns = this.columns();
+
         return items.map((item) => {
             const itemSelectHandler = (ev: InputEvent | PointerEvent) => {
                 const target = ev.target as HTMLElement;
@@ -379,7 +409,7 @@ export abstract class Table<T> extends AKElement implements TableLike {
             };
 
             const renderCheckbox = () =>
-                html`<td class="pf-c-table__check" role="cell">
+                html`<td aria-label="${msg("Select row")}" class="pf-c-table__check" role="button">
                     <label class="ignore-click"
                         ><input
                             type="checkbox"
@@ -419,9 +449,9 @@ export abstract class Table<T> extends AKElement implements TableLike {
                 </td>`;
             };
 
-            return html`<tbody role="rowgroup" class="${classMap(expandedClass)}">
+            return html`<tbody class="${classMap(expandedClass)}">
                 <tr
-                    role="row"
+                    aria-label="${this.rowLabel(item)}"
                     class="${this.checkbox || this.clickable ? "pf-m-hoverable" : ""}"
                     @click=${this.clickable
                         ? () => {
@@ -432,7 +462,13 @@ export abstract class Table<T> extends AKElement implements TableLike {
                     ${this.checkbox ? renderCheckbox() : nothing}
                     ${this.expandable ? renderExpansion() : nothing}
                     ${this.row(item).map((column, columnIndex) => {
-                        return html`<td data-column-index="${columnIndex}" role="cell">
+                        const columnLabel = columns[columnIndex]?.title;
+
+                        return html`<td
+                            aria-label=${ifDefined(columnLabel)}
+                            data-column-index="${columnIndex}"
+                            role="cell"
+                        >
                             ${column}
                         </td>`;
                     })}
@@ -445,7 +481,11 @@ export abstract class Table<T> extends AKElement implements TableLike {
         });
     }
 
-    renderToolbar(): TemplateResult {
+    //#endregion
+
+    //#region Toolbar
+
+    protected renderToolbar(): TemplateResult {
         return html` ${this.renderObjectCreate()}
             <ak-spinner-button
                 .callAction=${() => {
@@ -457,63 +497,74 @@ export abstract class Table<T> extends AKElement implements TableLike {
             >`;
     }
 
-    renderToolbarSelected(): SlottedTemplateResult {
+    protected renderToolbarSelected(): SlottedTemplateResult {
         return nothing;
     }
 
-    renderToolbarAfter(): SlottedTemplateResult {
+    protected renderToolbarAfter(): SlottedTemplateResult {
         return nothing;
     }
 
-    protected willUpdate(changedProperties: PropertyValues<this>): void {
-        if (changedProperties.has("page")) {
-            updateURLParams({
-                [this.#pageParam]: changedProperties.get("page"),
-            });
-        }
-        if (changedProperties.has("search")) {
-            updateURLParams({
-                [this.#searchParam]: changedProperties.get("search"),
-            });
-        }
-    }
-
-    renderSearch(): TemplateResult {
-        const runSearch = (value: string) => {
-            this.search = value;
-            this.page = 1;
-            this.fetch();
-        };
-
-        return !this.searchEnabled()
-            ? html``
-            : html`<div class="pf-c-toolbar__group pf-m-search-filter">
-                  <ak-table-search
-                      class="pf-c-toolbar__item pf-m-search-filter"
-                      value=${ifDefined(this.search)}
-                      .onSearch=${runSearch}
-                  >
-                  </ak-table-search>
-              </div>`;
-    }
-
-    renderToolbarContainer(): TemplateResult {
-        return html`<div class="pf-c-toolbar">
-            <div class="pf-c-toolbar__content">
+    protected renderToolbarContainer(): SlottedTemplateResult {
+        return html`<header class="pf-c-toolbar" role="toolbar" aria-label="${this.toolbarLabel}">
+            <div role="presentation" class="pf-c-toolbar__content">
                 ${this.renderSearch()}
-                <div class="pf-c-toolbar__bulk-select">${this.renderToolbar()}</div>
-                <div class="pf-c-toolbar__group">${this.renderToolbarAfter()}</div>
-                <div class="pf-c-toolbar__group">${this.renderToolbarSelected()}</div>
-                ${this.paginated ? this.renderTablePagination() : html``}
+                <div role="presentation" class="pf-c-toolbar__bulk-select">
+                    ${this.renderToolbar()}
+                </div>
+                <div role="presentation" class="pf-c-toolbar__group">
+                    ${this.renderToolbarAfter()}
+                </div>
+                <div role="presentation" class="pf-c-toolbar__group">
+                    ${this.renderToolbarSelected()}
+                </div>
+                ${this.paginated ? this.renderTablePagination() : nothing}
             </div>
+        </header>`;
+    }
+
+    //#endregion
+
+    //#region Search
+
+    #searchListener = (value: string) => {
+        this.search = value;
+        this.page = 1;
+        this.fetch();
+    };
+
+    protected searchEnabled(): boolean {
+        return false;
+    }
+
+    protected renderSearch(): SlottedTemplateResult {
+        if (!this.searchEnabled()) {
+            return nothing;
+        }
+
+        const isQL = this.supportsQL && this.hasEnterpriseLicense;
+
+        return html`<div class="pf-c-toolbar__group pf-m-search-filter ${isQL ? "ql" : ""}">
+            <ak-table-search
+                class="pf-c-toolbar__item pf-m-search-filter ${isQL ? "ql" : ""}"
+                .defaultValue=${this.search}
+                label=${ifDefined(this.searchLabel)}
+                placeholder=${ifDefined(this.searchPlaceholder)}
+                .onSearch=${this.#searchListener}
+                .supportsQL=${this.supportsQL}
+                .apiResponse=${this.data}
+            >
+            </ak-table-search>
         </div>`;
     }
 
-    firstUpdated(): void {
-        this.fetch();
-    }
+    //#endregion
 
-    /* The checkbox on the table header row that allows the user to "activate all on this page,"
+    //#region Chips
+
+    /**
+     * The checkbox on the table header row that allows the user to
+     * "activate all on this page,"
      * "deactivate all on this page" with a single click.
      */
     renderAllOnThisPageCheckbox(): TemplateResult {
@@ -538,11 +589,13 @@ export abstract class Table<T> extends AKElement implements TableLike {
         </td>`;
     }
 
-    /* For very large tables where the user is selecting a limited number of entries, we provide a
-     * chip-based subtable at the top that shows the list of selected entries. Long text result in
-     * ellipsized chips, which is sub-optimal.
+    /**
+     * For very large tables where the user is selecting a limited number of entries,
+     * we provide a chip-based subtable at the top that shows the list of selected entries.
+     *
+     * Long text result in ellipsized chips, which is sub-optimal.
      */
-    renderSelectedChip(_item: T): SlottedTemplateResult {
+    protected renderSelectedChip(_item: T): SlottedTemplateResult {
         // Override this for chip-based displays
         return nothing;
     }
@@ -551,7 +604,7 @@ export abstract class Table<T> extends AKElement implements TableLike {
         return this.checkbox && this.checkboxChip;
     }
 
-    renderChipGroup(): TemplateResult {
+    protected renderChipGroup(): TemplateResult {
         return html`<ak-chip-group>
             ${this.selectedElements.map((el) => {
                 return html`<ak-chip>${this.renderSelectedChip(el)}</ak-chip>`;
@@ -559,8 +612,10 @@ export abstract class Table<T> extends AKElement implements TableLike {
         </ak-chip-group>`;
     }
 
-    /* A simple pagination display, shown at both the top and bottom of the page. */
-    renderTablePagination(): TemplateResult {
+    /**
+     * A simple pagination display, shown at both the top and bottom of the page.
+     */
+    protected renderTablePagination(): SlottedTemplateResult {
         const handler = (page: number) => {
             this.page = page;
             this.fetch();
@@ -570,29 +625,32 @@ export abstract class Table<T> extends AKElement implements TableLike {
             <ak-table-pagination
                 class="pf-c-toolbar__item pf-m-pagination"
                 .pages=${this.data?.pagination}
-                .pageChangeHandler=${handler}
+                .onPageChange=${handler}
             >
             </ak-table-pagination>
         `;
     }
 
-    renderTable(): TemplateResult {
+    protected renderTable(): TemplateResult {
         const renderBottomPagination = () =>
             html`<div class="pf-c-pagination pf-m-bottom">${this.renderTablePagination()}</div>`;
 
-        return html`${this.needChipGroup ? this.renderChipGroup() : html``}
+        return html`${this.needChipGroup ? this.renderChipGroup() : nothing}
             ${this.renderToolbarContainer()}
-            <table class="pf-c-table pf-m-compact pf-m-grid-md pf-m-expandable">
-                <thead>
-                    <tr role="row" class="pf-c-table__header-row">
-                        ${this.checkbox ? this.renderAllOnThisPageCheckbox() : html``}
-                        ${this.expandable ? html`<td role="cell"></td>` : html``}
+            <table
+                aria-label=${this.label ? msg(str`Table of ${this.label}`) : msg("Table content")}
+                class="pf-c-table pf-m-compact pf-m-grid-md pf-m-expandable"
+            >
+                <thead aria-label=${msg("Table actions")}>
+                    <tr role="presentation" class="pf-c-table__header-row">
+                        ${this.checkbox ? this.renderAllOnThisPageCheckbox() : nothing}
+                        ${this.expandable ? html`<td role="cell"></td>` : nothing}
                         ${this.columns().map((col) => col.render(this))}
                     </tr>
                 </thead>
                 ${this.renderRows()}
             </table>
-            ${this.paginated ? renderBottomPagination() : html``}`;
+            ${this.paginated ? renderBottomPagination() : nothing}`;
     }
 
     render(): TemplateResult {
