@@ -1,11 +1,13 @@
-import { render } from "@goauthentik/elements/tests/utils.js";
+import "../Expand.js";
+
+import { akExpand } from "../Expand.js";
+
+import { render } from "#elements/tests/utils";
+
 import { $, expect } from "@wdio/globals";
 
 import { html } from "lit";
 
-import "../Expand.js";
-import { akExpand } from "../Expand.js";
-
 describe("ak-expand", () => {
     afterEach(async () => {
         await browser.execute(async () => {
