@@ -1,11 +1,13 @@
-import { render } from "@goauthentik/elements/tests/utils.js";
+import "../LoadingOverlay.js";
+
+import { akLoadingOverlay } from "../LoadingOverlay.js";
+
+import { render } from "#elements/tests/utils";
+
 import { $, expect } from "@wdio/globals";
 
 import { html } from "lit";
 
-import "../LoadingOverlay.js";
-import { akLoadingOverlay } from "../LoadingOverlay.js";
-
 describe("ak-loading-overlay", () => {
     it("should render the default loader", async () => {
         render(html`<ak-loading-overlay></ak-loading-overlay>`);
