@@ -1,12 +1,13 @@
-import "@goauthentik/admin/admin-settings/AdminSettingsFooterLinks.js";
-import { render } from "@goauthentik/elements/tests/utils.js";
-import { $, expect } from "@wdio/globals";
+import "#admin/admin-settings/AdminSettingsFooterLinks";
+import "../ak-array-input.js";
 
-import { html } from "lit";
+import { render } from "#elements/tests/utils";
 
 import { FooterLink } from "@goauthentik/api";
 
-import "../ak-array-input.js";
+import { $, expect } from "@wdio/globals";
+
+import { html } from "lit";
 
 const sampleItems: FooterLink[] = [
     { name: "authentik", href: "https://goauthentik.io" },
