@@ -1,6 +1,6 @@
-import { applyDocumentTheme } from "@goauthentik/common/theme.js";
+import { applyDocumentTheme } from "#common/theme";
 
-import { TemplateResult, render as litRender } from "lit";
+import { render as litRender, TemplateResult } from "lit";
 
 /**
  * A special version of render that ensures our stylesheets:
