@@ -1,4 +1,4 @@
-import { AKElement } from "@goauthentik/elements/Base";
+import { AKElement } from "#elements/Base";
 
 import { CSSResult } from "lit";
 import { property } from "lit/decorators.js";
@@ -15,7 +15,5 @@ export abstract class BaseUserSettings extends AKElement {
     @property()
     configureUrl?: string;
 
-    static get styles(): CSSResult[] {
-        return [PFBase, PFButton, PFForm, PFFormControl];
-    }
+    static styles: CSSResult[] = [PFBase, PFButton, PFForm, PFFormControl];
 }
