@@ -1,16 +1,21 @@
-import { PFSize } from "@goauthentik/common/enums.js";
-import { globalAK } from "@goauthentik/common/global";
-import { rootInterface } from "@goauthentik/common/theme";
-import { truncateWords } from "@goauthentik/common/utils";
-import "@goauthentik/elements/AppIcon";
-import { AKElement } from "@goauthentik/elements/Base";
-import "@goauthentik/elements/Expand";
-import "@goauthentik/user/LibraryApplication/RACLaunchEndpointModal";
-import type { RACLaunchEndpointModal } from "@goauthentik/user/LibraryApplication/RACLaunchEndpointModal";
-import type { UserInterface } from "@goauthentik/user/index.entrypoint.js";
+import "#elements/AppIcon";
+import "#elements/Expand";
+import "#user/LibraryApplication/RACLaunchEndpointModal";
+
+import { PFSize } from "#common/enums";
+import { globalAK } from "#common/global";
+import { rootInterface } from "#common/theme";
+import { truncateWords } from "#common/utils";
+
+import { AKElement } from "#elements/Base";
+
+import type { UserInterface } from "#user/index.entrypoint";
+import type { RACLaunchEndpointModal } from "#user/LibraryApplication/RACLaunchEndpointModal";
+
+import { Application } from "@goauthentik/api";
 
 import { msg } from "@lit/localize";
-import { CSSResult, TemplateResult, css, html, nothing } from "lit";
+import { css, CSSResult, html, nothing, TemplateResult } from "lit";
 import { customElement, property, query } from "lit/decorators.js";
 import { classMap } from "lit/directives/class-map.js";
 import { ifDefined } from "lit/directives/if-defined.js";
@@ -20,8 +25,6 @@ import PFButton from "@patternfly/patternfly/components/Button/button.css";
 import PFCard from "@patternfly/patternfly/components/Card/card.css";
 import PFBase from "@patternfly/patternfly/patternfly-base.css";
 
-import { Application } from "@goauthentik/api";
-
 @customElement("ak-library-app")
 export class LibraryApplication extends AKElement {
     @property({ attribute: false })
@@ -36,40 +39,38 @@ export class LibraryApplication extends AKElement {
     @query("ak-library-rac-endpoint-launch")
     racEndpointLaunch?: RACLaunchEndpointModal;
 
-    static get styles(): CSSResult[] {
-        return [
-            PFBase,
-            PFCard,
-            PFButton,
-            css`
-                .pf-c-card {
-                    --pf-c-card--BoxShadow: var(--pf-global--BoxShadow--md);
-                }
-                .pf-c-card__header {
-                    justify-content: space-between;
-                    flex-direction: column;
-                }
-                .pf-c-card__header a {
-                    display: flex;
-                    flex-direction: column;
-                    justify-content: center;
-                }
-                a:hover {
-                    text-decoration: none;
-                }
-                .expander {
-                    flex-grow: 1;
-                }
-                .pf-c-card__title {
-                    text-align: center;
-                    /* This is not ideal as it hard limits us to 2 lines of text for the title
+    static styles: CSSResult[] = [
+        PFBase,
+        PFCard,
+        PFButton,
+        css`
+            .pf-c-card {
+                --pf-c-card--BoxShadow: var(--pf-global--BoxShadow--md);
+            }
+            .pf-c-card__header {
+                justify-content: space-between;
+                flex-direction: column;
+            }
+            .pf-c-card__header a {
+                display: flex;
+                flex-direction: column;
+                justify-content: center;
+            }
+            a:hover {
+                text-decoration: none;
+            }
+            .expander {
+                flex-grow: 1;
+            }
+            .pf-c-card__title {
+                text-align: center;
+                /* This is not ideal as it hard limits us to 2 lines of text for the title
                     of the application. In theory that should be fine for most cases, but ideally
                     we don't do this */
-                    height: 48px;
-                }
-            `,
-        ];
-    }
+                height: 48px;
+            }
+        `,
+    ];
 
     renderExpansion(application: Application) {
         const { me, uiConfig } = rootInterface<UserInterface>();
@@ -101,7 +102,7 @@ export class LibraryApplication extends AKElement {
             return html`<div class="pf-c-card__header">
                     <a
                         @click=${() => {
-                            this.racEndpointLaunch?.onClick();
+                            this.racEndpointLaunch?.show();
                         }}
                     >
                         <ak-app-icon
@@ -114,7 +115,7 @@ export class LibraryApplication extends AKElement {
                 <div class="pf-c-card__title">
                     <a
                         @click=${() => {
-                            this.racEndpointLaunch?.onClick();
+                            this.racEndpointLaunch?.show();
                         }}
                     >
                         ${this.application.name}
