@@ -1,10 +1,10 @@
-import { $ } from "@wdio/globals";
-
 import Page from "../pageobjects/page.js";
 
+import { $ } from "@wdio/globals";
+
 export default class AdminPage extends Page {
-    public async pageHeader() {
-        return await $(">>>ak-page-header").$('>>>slot[name="header"]');
+    public pageHeader() {
+        return $(">>>ak-page-navbar").$(".page-title");
     }
 
     async openApplicationsListPage() {
