@@ -1,14 +1,14 @@
-import { $ } from "@wdio/globals";
-
 import Page from "../page.js";
 
+import { $ } from "@wdio/globals";
+
 export class ApplicationForm extends Page {
     async name() {
         return await $('>>>ak-text-input[name="name"]').$(">>>input");
     }
 
     async uiSettings() {
-        return await $(">>>ak-form-group").$('button[aria-label="UI Settings"]');
+        return $('>>>ak-form-group[label="UI Settings"]');
     }
 
     async launchUrl() {
